estimates clear
clear all
mata: mata clear

/*----------------------------------------------------------------
	Replicate tables and appendix material from:
	
		Casey, Glennerster, Miguel and Voors 
		"Long Run Effects of Aid: Forecasts and Evidence from Sierra Leone" 
		
	NOTE: Running this file requires installation of several user written commands
	
	This do file uses the following de-identified datasets:
	
	- public_SES.dta
	- public_expert_data.dta

	And the following file from the replication files for the paper:
		Casey, Glennerster, and Miguel "Reshaping Instutions: Evidence on
		Aid Impacts Using a Preanalysis Plan"
		
	- gbf_analysis.dta
	
	See: https://dataverse.harvard.edu/dataset.xhtml?persistentId=hdl:1902.1/21708
	
	And generates the following outputs for tables in the main text and appendix:
	
	- Table 1: Table_1_2009.csv, Table_1_2016.csv, Table_1_decay.csv 
	- Table 2: Table_2.csv 
	- Appendix Table A1: Table_A1_2009.csv, Table_A1_2016.csv, Table_A1_decay.csv 
	- Appendix Table A3: Table_A3.csv
	- Appendix Table A4: Table_A4.csv
	- Appendix Table A5: Table_A5.csv
	- Appendix Table A6: Table_A6_BOMBALI.csv, Table_A6_BONTHE.csv
	- Appendix Table A7: Table_A7.csv

	and the following outputs for figures in the main text and appendix: 
	
	- Figure 3: fig3.png
	- Figure 4: fig4.png
	- Figure 5: fig5_a.png, fig5_b.png
	- Figure 6: fig6_panela.png, fig6_panelb.png, fig6_panelc.png
	- Figure A1: figa1.png
	- Figure A2: figa2.png
	- Figure A3: figa3_panela.png, figa3_panelb.png
	
	It also generates in-text values and estimates  
	
	NB: For FDR q-values found in Table 1, Table 2 and Table A1 please follow the instructions in fdr_sharpened_qvalues.do by Anderson (2008)
	
------------------------------------------------------------------------------*/

*** START HERE: set your working directory to where you have saved the folder on your device:
*cd "[your directory]/cdd-replication/"
set seed 500


*** Uncomment if you have not installed these user-written commands
* ssc install splitvallabels
* ssc install estout
* ssc install stripplot 
* net install grc1leg2.pkg

***************************
*   PART I: FORMAT DATA   *
***************************

********************************************************************************
*********************** Generating New Outcome Variables ***********************
********************************************************************************


*NB: days_brush, meet_com, meet_wmn, meet_yth, out_trader, chf_age, yth_chf,
* vh_fem, vh_youth are cleaned outside of this do file as they use redacted vars
	
use "data/public_SES.dta", clear


foreach var in j15 j7 k6 e1 e2 e3 l2_a l2_b l2_c l2_d l2_e l2_f g4 g25 g23 g24 g26 g22 g21 g23 g24 g6 g7 g8 h15 d1 g1 e12 g9 e6 e5 c1_b c2_b c3_b c4_b c5_b c6_b c7_b c8_b c9_b c10_b c11_b c12_b g3 f9 g2 l3 h4 h5 h6 h7 h8 h9 h10 h11 h12 h13 h14 g20 {
		recode `var' (1=1) (2=0)
			}

	* Name / construct consistently with 2009
	gen bank_acct=g1
	label var bank_acct "Bank Account"

	gen vdc=e12
	label var vdc "Village Development Committee"

	gen vdp=g9
	label var vdp "Village Development Plan"

	gen vis_lc=e6
	label var vis_lc "Visit by Local Councillor"

	gen vis_wdc=e5
	label var vis_wdc "Visit by WDC Member"

	
	*Recode public goods to dummies=1 if existing and functional 
	foreach x in 1 2 4 5 6 7 8 9 10 11 12{
		replace c`x'_b=0 if inrange(c`x'_c, 2, 3)
		}
	replace c3_b=0 if c3a_b==0 & c3b_b==0

	gen f_psch= c1_b
	label var f_psch "Primary school"
	
	gen f_phu=c2_b
	label var f_phu "Public health unit"

	gen f_well= c3_b
	label var f_well "Well"

	gen f_dryflr=c4_b
	label var f_dryflr "Drying floor"

	gen f_grnstr=c5_b
	label var f_grnstr "Grain store"

	gen f_comcntr= c6_b
	label var f_comcntr "Community center"

	gen f_palava= c7_b
	label var f_palava "Palava hut"

	gen f_barrie= c8_b
	label var f_barrie "Community barrie"

	gen f_market=c9_b
	label var f_market "Market"

	gen f_latrine=c10_b
	label var f_latrine "Latrine"

	gen func_sports=c11_b
	label var func_sports "Sports field"

	gen func_tba=c12_b
	label var func_tba "Traditional birth attendant"
	
	gen footunif=g3
	label var footunif "Sports teams have uniforms"
	
	gen no_bush=l11
	label var no_bush "How bushy is footpath"
	
	gen proposal=f9
	label var proposal "Taken a project proposal to an external funder"
	
	gen seedbank=g2
	label var seedbank "Seedbank"

	gen betteroff=0
	replace betteroff=1 if inlist(l10, 1, 2)
	label var betteroff "Better off"

	gen petty=l3
	label var petty "Petty trading"

	egen tot_goods=rowtotal(h4 h5 h6 h7 h8 h9 h10 h11 h12 h13 h14)
	label var tot_goods "Number of goods accessible"
	
	gen tot_newbiz=h16
	label var tot_newbiz "Number of new businesses"

	gen tot_petty=h1
	label var tot_petty "Number of petty businesses"
	
	gen training=g19
	label var training "Training"

	gen commfarm=g20
	label var commfarm "Community farm"
	
	gen commtchr=d1
	label var commtchr "Community teachers"
	
	gen mkt_grp=h15
	label var mkt_grp "Market group"

	gen disabled_ldr=g8
	label var disabled_ldr "Disabled leader"
	
	gen disabled_meet=g7
	label var disabled_meet "Disabled attend community meetings"
	
	gen minutes=g6
	label var minutes "Minutes taken at recent meeting "
	
	gen nocorrupt=g10
	recode nocorrupt (1=0) (2=1)
	label var nocorrupt "Financial mismanagement/ corruption"

	gen trust_lc_chf=g24-g23
	label var trust_lc_chf "Relative trust in local councillors over chiefs"

	gen osusu =g11
	label var osusu "Number of credit/savings groups "
	
	gen trust_cg=g25
	label var trust_cg "Trust in central government "
	
	gen trust_chf=g23
	label var trust_chf "Trust in chiefdom officials"
	
	gen trust_lc=g24
	label var trust_lc "Trust in local councillors"
		
	gen trust_ngo=g26
	label var trust_ngo "Trust in NGOs"
		
	gen trust_out=g22
	label var trust_out "Trust in people outside community"
	
	gen trust_own=g21
	label var trust_own "Trust in community members"

	gen fishcoop=g4
	label var fishcoop "Fishing groups"
	
	gen mbr_pta=g12
	label var mbr_pta "Number of active PTA/ CTA groups"
	
	gen mbr_rel=g13
	label var mbr_rel "Number of active religious groups"
	
	gen mbr_sav=g14
	label var mbr_sav "Number of active saving groups"
	
	gen mbr_seed=g15
	label var mbr_seed "Number of active seed multiplication groups"
	
	gen mbr_soc=g16
	label var mbr_soc "Number of active social clubs"
	
	gen mbr_wom=g17
	label var mbr_wom "Number of active women's groups"
	
	gen mbr_yth=g18
	label var mbr_yth "Number of active youth groups"

	egen disp_ind=rowmean(l2_a l2_b l2_c l2_d l2_e l2_f)
	label var disp_ind "Displayed information about local governance"
	
	gen vis_pc=0
	replace vis_pc=1 if inlist(e7, 1, 3)
	label var vis_pc "Visit by paramount chief"

	gen stand_lc=e3
	label var stand_lc "Someone in community stood for local council"
	
	gen stand_pc=e1
	label var stand_pc "Someone in community stood for paramount chief"
	
	gen stand_sc=e2
	label var stand_sc "Someone in community stood for secton chief"
	
	gen stand_wdc=0
	replace stand_wdc=1 if e4==1
	label var stand_wdc "Someone in community stood for WDC"

	gen no_conflict=-1*e8
	label var no_conflict "Number of people needing help to resolve conflict"

	gen no_fight=-1*e9
	label var no_fight "Number of people involved in physical fight"

	gen no_theft=-1*e10
	label var no_theft "Number of people with items stolen"

	gen no_witch=-1*e11 
	label var no_witch "Number of victims of witchcraft (juju)"


*************
/*  Primary Outcomes: Ebola */	
*************

	gen get_eb=wordcount(k1) 
	la var get_eb "Correct answers in 'how can you get Ebola?'" 
	replace get_eb=0 if k1=="13" 
		
	gen sympt_eb=wordcount(k2) 
	la var sympt_eb "Correct answers in 'what symptoms show up when someone has Ebola?'" 
	replace sympt_eb=0 if k2=="20" | k2=="19"
		
	gen protect_eb=wordcount(k3)
	la var protect_eb "Correct answers in 'What can you do to protect yourself against Ebola?'" 
	gen last2=substr(k3, -2, 2)
	destring last2, replace
	replace protect_eb = protect_eb -1 if inrange(last2, 16, 20)
	list id_vill k3 protect_eb if inrange(last2, 16, 20)
	drop last2
	replace protect_eb=protect_eb-1 if id_vill==207 // One of those is wrong!
		
	gen days_eb = 0 
	la var days_eb "Answers 21 days in 'How many DAYS can it take for the first to symptoms arise?'" 
	replace days_eb = 1 if k4==21
		
	gen air_eb=k5 
	la var air_eb "No to 'Can Ebola spread through air?'"
	recode air_eb (1=0) (2=1)
		
	gen spread_eb = k6 
	la var spread_eb "No to 'Can spmeone spread Ebola even they show any symptoms?'"  

	gen salt_eb=k7  
	recode salt_eb (1=0) (2=1) 
	la var salt_eb "No to 'Drinking salt water can help cure Ebola?'"
		
	gen chlorine_eb =k8
	recode chlorine_eb (1=0) (2=1) 
	la var chlorine_eb "No to 'Drinking chlorine can help cure Ebola?'"
		
	gen hotline_eb = j13 
	la var hotline_eb "Do you know [correct] the Ebola hotline number?" 
		
	gen task_eb =j7
	la var task_eb "During the Ebola crisis, did you have an Ebola Task Force in your village?"
		
	gen seekwestern = 0  
	replace seekwestern = 1 if j9_1 == 2 | j9_1 == 3 
	la var seekwestern "Communities are more likely to go to formal health facilities (nurse, hospital)"
		
	gen seekwestern_eb = 0 
	replace seekwestern_eb = 1 if j10 == 2 | j10 == 3 
	la var seekwestern_eb "Communities are more likely to go to formal health facilities for Ebola (nurse, hospital)"
		
	gen law_eb =j15
	la var law_eb "Did you create community bye-laws in relation to Ebola?"
		
	* j28 (Was there any violence (quarrels, physical fighting) related to Ebola in your village?) dropped due to high non response, just 14 communities provided responses, cant say missing is yes
	* j29 (Did people hide Ebola cases in your village?) dropped due to high non response, 14 responses

	
*************
/*  Secondary Outcomes: Ebola */	
*************

	gen suspect_eb = 0  
	replace suspect_eb = j3_a if j3_a!=. 
	label var suspect_eb "Someone in village suspected to have ebola"
	
	gen infect_eb = 0  
	replace infect_eb = j4_a if j4_a!=.
	label var infect_eb "Someone in village infected with ebola"
	
	gen dead_eb = 0  
	replace dead_eb = j5_a if j5_a!=. 
	label var dead_eb "Someone in village died of ebola"
	* excluded j11  (Did you report on suspected Ebola cases in your community?) dropped due to high non response,, only 20 responses



*************
/*  New SCA Outcomes */	
*************

*for H1 mean_mc_score

*for H4 techscore policyscore expscore winner

*for H5 
 
 *Potential managers selection deliberation done in public debate
 
	destring ms_a14_a, replace
	replace ms_a14_a=0 if ms_a14_a==2
	replace ms_b11_a=0 if ms_b11_a==2
	gen ms_debate = (ms_a14_a + ms_b11_a)/2
	label var ms_debate "Potential managers selection deliberation done in public debate"
 
 *Less concentrated deliberation in manager selection
	gen ms_cons = (ms_a16 + ms_b13)/2
	label var ms_cons "Less concentrated deliberation in manager selection"
	
 
 *Enumerator account of how democratically the group evenutally came to a decision about who the  potential project managers ranging from 5 = open discussion followed by group vote to 1 = chief and/or elders decide without other input
	gen ms_demo = (ms_a15 + ms_b12)/2
	label var ms_demo "Enumerator account of how democratically the group evenutally came to a decision about who the  potential project managers"
 
 *Time of deliberation of manager selection process
	* ms_dur
	* This variable is constructed using times that have been masked for public use
	tab ms_dur,m

 
 *Enumerator account of how actively women participated in the deliberation on the selection of potential project managers  compared to men, ranging from 5 = no difference between women and men to 1 = women not active at all compared to men
	gen ms_wmn_active = (ms_a17 + ms_b14)/2
	label var ms_wmn_active "Enumerator account of how actively women participated in the deliberation on the selection of potential project managers compared to men"
 
 *Enumerator account of how actively youth participated in the deliberation on the selection of potential project managers compared to non-youth (over 35 years), ranging from 5 = no difference between youth and non-youth to 1 = youth not active at all compared to non-youth
	gen ms_yth_active = (ms_a18 + ms_b15)/2
	label var ms_yth_active "Enumerator account of how actively youth participated in the deliberation on the selection of potential project managers compared to non-youth"
 

 *Enumerator record of total public speakers durings selection of potential project managers
	destring ms_a11 ms_a12, replace
	gen ms_a11_12 = ms_a11+ms_a12
	gen ms_spkr = (ms_a11_12+ms_b10)/2
	label var ms_spkr "Enumerator record of total public speakers durings selection of potential project managers"
 
 *Enumerator record of total women public speakers during selection of potential project managers
	gen ms_wmn = (ms_b10_b+ms_a11)/2
	label var ms_wmn "Enumerator record of total women public speakers during selection of potential project managers"
 
 *Enumerator record of total youth (18-35 years) public speakers during selection of potential project managers	
	gen  ms_yth= ms_b10_a 
	label var ms_yth "Enumerator record of total youth (18-35 years) public speakers during selection of potential project managers"
	
 *Did a vote occur during the project leader nomination discussion
	gen ms_vote= ms_a14_d
	replace ms_vote=0 if ms_vote==2
	label var ms_vote "Did a vote occur during the project leader nomination discussion"
	


*for H6 
	*enumerator reports on whether "chief decided" project leader nominations - i.e. not equal to response codes 1 or 2
	recode ms_a15 (5=1) (4=1) (3=1) (2=0) (1=0)
	recode ms_b12 (5=1) (4=1) (3=1) (2=0) (1=0)
	gen ms_nochief  = (ms_a15 + ms_b12)/2
	label var ms_nochief "Enumerator reports on whether chief decided project leader nomination"


	* wards
	tab r_ward, gen(ward_)


	
save "data/SES_analysis.dta", replace

***************************
*   PART II: Analysis     *
***************************

********************************************************************************
************************************ MACROS ************************************
********************************************************************************

* long run all outcomes
* vars_h* outcome per hypothesis
* pvars_h* restrict to exact same outcomes by 2009 / 2016 survey round

local indepvars "t1 tothhs road ward*" 

local vars_h1 "bank_acct vdc vdp vis_lc vis_wdc     mean_mc_score" 
local vars_h2 "days_brush f_psch f_phu f_well  f_dryflr f_grnstr f_comcntr f_palava f_barrie f_market f_latrine func_sports func_tba footunif no_bush proposal seedbank"
local vars_h3 "bank_acct betteroff out_trader petty tot_goods tot_newbiz tot_petty training"
local vars_h4 "vdc days_brush no_bush proposal commfarm commtchr mkt_grp       techscore policyscore expscore winner"
local vars_h5 "disabled_ldr disabled_meet meet_com meet_wmn meet_yth minutes nocorrupt ms_debate ms_cons ms_demo ms_dur ms_wmn_active ms_yth_active ms_spkr ms_wmn ms_yth ms_vote"
local vars_h6 "chf_age  trust_lc_chf    ms_nochief ms_vote"
local vars_h7 "mkt_grp osusu trust_cg trust_chf trust_lc trust_ngo trust_out trust_own"
local vars_h8 "mkt_grp osusu fishcoop mbr_pta mbr_rel mbr_sav mbr_seed mbr_soc mbr_wom mbr_yth"
local vars_h9 "vis_lc vis_wdc disp_ind vis_pc"
local vars_h10 "vdc vdp stand_lc stand_pc stand_sc stand_wdc"
local vars_h11 "no_conflict no_fight no_theft no_witch"
local vars_h12 "vh_fem vh_youth"



* create locals dropping mechanical outcomes 
* dropped "vdc" and "bank_acct"	
local vars_mech_h1 "vdp vis_lc vis_wdc     mean_mc_score"
local vars_mech_h2 "days_brush f_psch f_phu f_well  f_dryflr f_grnstr f_comcntr f_palava f_barrie f_market f_latrine func_sports func_tba footunif no_bush proposal seedbank"
local vars_mech_h3 "betteroff out_trader petty tot_goods tot_newbiz tot_petty training"
local vars_mech_h4 "days_brush no_bush proposal commfarm commtchr mkt_grp       techscore policyscore expscore winner"
local vars_mech_h5 "disabled_ldr disabled_meet meet_com meet_wmn meet_yth minutes nocorrupt      ms_debate ms_cons ms_demo ms_dur ms_wmn_active ms_yth_active ms_spkr ms_wmn ms_yth ms_vote"
local vars_mech_h6 "chf_age trust_lc_chf     ms_nochief ms_vote"
local vars_mech_h7 "mkt_grp osusu trust_cg trust_chf trust_lc trust_ngo trust_out trust_own"
local vars_mech_h8 "mkt_grp osusu fishcoop mbr_pta mbr_rel mbr_sav mbr_seed mbr_soc mbr_wom mbr_yth"
local vars_mech_h9 "vis_lc vis_wdc disp_ind vis_pc"
local vars_mech_h10 "vdp stand_lc stand_pc stand_sc stand_wdc"
local vars_mech_h11 "no_conflict no_fight no_theft no_witch"
local vars_mech_h12 "vh_fem vh_youth"

* create locals dropping all sca outcomes 
* dropped: "H1: meanscore   H4:  techscore policyscore expscore winner H5: ms_debate ms_cons ms_demo ms_dur ms_wmn_active ms_yth_active ms_spkr ms_wmn ms_yth ms_vote  H6: ms_nochief ms_vote"	

local vars_nosca_h1 "bank_acct vdc vdp vis_lc vis_wdc" 
local vars_nosca_h2 "days_brush f_psch f_phu f_well  f_dryflr f_grnstr f_comcntr f_palava f_barrie f_market f_latrine func_sports func_tba footunif no_bush proposal seedbank"
local vars_nosca_h3 "bank_acct betteroff out_trader petty tot_goods tot_newbiz tot_petty training"
local vars_nosca_h4 "vdc days_brush no_bush proposal commfarm commtchr mkt_grp       "
local vars_nosca_h5 "disabled_ldr disabled_meet meet_com meet_wmn meet_yth minutes nocorrupt     "
local vars_nosca_h6 "chf_age trust_lc_chf     "
local vars_nosca_h7 "mkt_grp osusu trust_cg trust_chf trust_lc trust_ngo trust_out trust_own"
local vars_nosca_h8 "mkt_grp osusu fishcoop mbr_pta mbr_rel mbr_sav mbr_seed mbr_soc mbr_wom mbr_yth"
local vars_nosca_h9 "vis_lc vis_wdc disp_ind vis_pc"
local vars_nosca_h10 "vdc vdp stand_lc stand_pc stand_sc stand_wdc"
local vars_nosca_h11 "no_conflict no_fight no_theft no_witch"
local vars_nosca_h12 "vh_fem vh_youth"

* create locals with only sca outcomes 
local vars_sca_h1 "mean_mc_score" 
local vars_sca_h4 "techscore policyscore expscore winner"
local vars_sca_h5 "ms_debate ms_cons ms_demo ms_dur ms_wmn_active ms_yth_active ms_spkr ms_wmn ms_yth ms_vote"
local vars_sca_h6 "ms_nochief ms_vote"

* ebola - new for 2016 round
local vars_h13 "task_eb air_eb days_eb get_eb hotline_eb  law_eb protect_eb salt_eb chlorine_eb spread_eb sympt_eb  "
local vars_h14 "suspect_eb infect_eb dead_eb"
	* abusing hypothesis notation here for efficiency - these are secondary outcomes


*  2009 replication of results *
local p_me_corevars_1 "vdc vis_wdc vis_lc met_councilor att_wdc"
local e_me_corevars_1 "vdp bank_acct"
local p_me_corevars_2 "f_psch f_phu f_well f_dryflr f_grnstr f_comcntr f_barrie f_palava f_market proposal"
local e_me_corevars_2 "f_latrine func_tba func_sports seedbank footunif tarp_public no_bush days_brush"
local p_me_corevars_3 "petty betteroff assets quintile tot_sources "
local e_me_corevars_3 "bank_acct tot_petty tot_goods tot_newbiz income training newbiz sold_agric sold_other out_trader"
local p_me_corevars_7 "trust_own trust_out trust_chf trust_lc trust_cg osusu hwallet hmarket rmarket"
local e_me_corevars_7 "trust_ngo trust_pol mkt_grp"
local p_me_corevars_4 "wkcomfrm brush vdc proposal commfarm  commtchr"
local e_me_corevars_4 "vchr_tot vchr_self anycard cards tarp tarp_freq mkt_grp no_bush days_brush"
local p_me_corevars_8 "chumos dues ttch_oth  osusu mbr_pta mbr_soc" 
local e_me_corevars_8 "mbr_sav mbr_rel mbr_trad mbr_fish mbr_seed mbr_wom mbr_youth fishcoop mkt_grp" 
local p_me_corevars_9 "name_lc name_chr name_sc name_pc name_elec name_tax name_proj radio vis_wdc vis_lc disp_ind"
local e_me_corevars_9 "gift_meet gift_two gift_choice info_gift info_tarp vis_pc"
local p_me_corevars_5 "meet_com "
local e_me_corevars_5 "gift_meet wygift_meet proj_dem gift_dem gift_say tarp_say gift_big mtng_salt mtng_tarp mtng_cards dem_salt dem_tarp dem_cards say_salt say_tarp say_cards meet_tot meet_wmn meet_yth  spkr_tot spkr_wmn spkr_yth vote debate nohanghd noprivol democ  role_wmn role_yth duration maj_gift meet_salt equal_salt meet_tarp equal_tarp meet_cards equal_cards minutes disabled_meet disabled_ldr show_tarp store_tarp nocorrupt ben_salt ben_tarp tarp_public" 
local p_me_corevars_10 "vote_pres1 vote_local met_councilor att_wdc change_council change_chiefdom stand_pc stand_sc stand_lc stand_wdc vdc"
local e_me_corevars_10 "cvote_pres1 vote_pres2 cvote_pres2 cvote_local discuss_politics council_listen vdp" 
local p_me_corevars_11 "nomon_conflict no_theft no_fight no_witch "
local e_me_corevars_11 "violence_bad nobeatwife nobeatchild no_conflict " 
local p_me_corevars_6 "resolve_nottrad trust_lc_chf"
local e_me_corevars_6 "gift_say rtarp_public question_auth leader_wmn leader_yth proj_dem spend_lc_chf list_lc_chf notchf_salt notrad_salt notchf_tarp notrad_tarp notchf_cards notrad_cards vote chf_consult tstore_notchf not_trad_salt not_trad_tarp not_trad_card gift_who tarp_say tarp_stored" 
local e_me_corevars_12 "nobeatwife leader_yth leader_wmn bribebad strangeok noforcework youthtreat vh_fem vh_youth " 


********************************************************************************
************************************ TABLE 1 ***********************************
********************************************************************************

*************
/*  2016 Outcomes */	
*************

use "data/SES_analysis.dta", clear

foreach num of numlist 1(1)14{
	local i = `num'
	foreach var of varlist  `vars_h`i'' {
		local l = `l' + 1
		qui sum `var' if t1==0
		qui gen `var'_mean=r(mean)
		qui gen `var'_sd=r(sd)
		qui gen std_`i'_`l'=(`var'-`var'_mean)/`var'_sd
		* impute missing values
		egen mean_std_`i'_`l'_t=mean( std_`i'_`l') if t1==1
		replace std_`i'_`l'=mean_std_`i'_`l'_t if t1==1 & std_`i'_`l'==.
		replace std_`i'_`l'=0 if t1==0 & std_`i'_`l'==.
		local zscore_string_`i'="`zscore_string_`i''" + " std_`i'_`l'"
			}
	egen zscore_h`i'=rowmean(`zscore_string_`i'')
**#
	local zscore_string_`i'=""
	local l = 0
	drop *_mean *_sd mean_std_*
	}

	foreach num of numlist 1(1)13{
	reg  zscore_h`num' `indepvars', robust
	display "Hypothesis number in Table= `num'"
	estimates store tab1col1_`num'
	}

* Drop duplicates for family-level estimates (i.e. outcomes that appear under multiple hypos within a family)
	drop std_3_1 // bank_acct in H1 and H3
	drop std_10_1 //vdc in H4 and H10
	drop std_7_1 std_8_1 //mkt_grp in H4, H7 and H8
	drop std_6_4  //ms_vote 
	drop std_8_2 // osusu in H7 and H8

	egen zscore_famA=rowmean(std_1_* std_2_* std_3_*)
	egen zscore_famB=rowmean(std_4_* std_5_* std_6_* std_7_* std_8_* std_9_* std_10_* std_11_* std_12_*)

	reg  zscore_famA `indepvars', robust
		estimates store tab1col1_famA
		* Store for Fig 2 (TE, CI lower, CI upper, SE)
		mata: te_2016_A = st_matrix("r(table)")[1,1], st_matrix("r(table)")[5,1], st_matrix("r(table)")[6,1], st_matrix("r(table)")[2,1]
	reg  zscore_famB `indepvars', robust
		estimates store tab1col1_famB
		* Store for Fig 2 (TE, CI lower, CI upper, SE)
		mata: te_2016_B = st_matrix("r(table)")[1,1], st_matrix("r(table)")[5,1], st_matrix("r(table)")[6,1], st_matrix("r(table)")[2,1]
		
	drop std_*

	* output
	esttab tab1col1_* using "tables/Table_1_2016.csv", cells(b(star fmt(%9.3f)) se(par fmt(%9.3f)) p(par("[" "]") fmt(%9.3f))) stats(N, fmt( %9.0f %9.2f)) style(fixed) starlevels(* .1 ** .05 *** .01) keep (t1) replace /// 
	title("Table 1. Panel A1 Long Run Effects 2016 outcomes") mtitles("H1 - Implementation" "H2 - Local Public Infrastructure" "H3 - Economic welfare" "H4 - Collective action"	"H5 - Inclusion"	"H6 - Systems of authority"	"H7 - Trust"	"H8 - Groups and networks"	"H9 - Information"	"H10 - Participation"	"H11 - Crime and conflict"	"H12 - Attitudes" "H13 - Response to Ebola" "Family A" "Family B") ///
		addnotes("")	

* keep zscores for decay model (save to merge with 2009 zscores)
preserve 
	keep id_vill zscore_* `indepvars' 
	ren zscore_* zscore1_* 
	save "temp/temp_zscores2016.dta", replace 
restore  
	
	

*************
/*  2009 Outcomes */	
*************

use "data/gbf_analysis.dta", clear

drop if post==0
ren t t1
	
* gen z score 
foreach num of numlist 1 2 3 4 7 8 9 10 11 12{
	local i = `num'
	foreach var of varlist  `p_me_corevars_`i'' `e_me_corevars_`i''{
		local l = `l' + 1
		qui sum `var' if t1==0
		qui gen `var'_mean=r(mean)
		qui gen `var'_sd=r(sd)
		qui gen std_`i'_`l'=(`var'-`var'_mean)/`var'_sd
		qui egen mean_std_`i'_`l'_t=mean( std_`i'_`l') if t1==1
		qui replace std_`i'_`l'=mean_std_`i'_`l'_t if t1==1 & std_`i'_`l'==.
		qui replace std_`i'_`l'=0 if t1==0 & std_`i'_`l'==.
		local zscore_string_`i'="`zscore_string_`i''" + " std_`i'_`l'"
			}
	egen zscore_`i'=rowmean(`zscore_string_`i'')
	local zscore_string_`i'=""
	local l = 0
	drop *_mean *_sd mean_std_*
	}

* NOTE: large number of outcomes in H5 and H6 require longer strings hand coded below	
foreach num of numlist 5 6{ 
	local i = `num'
	foreach var of varlist  `p_me_corevars_`i'' `e_me_corevars_`i''{
		local l = `l' + 1
		qui sum `var' if t1==0
		qui gen `var'_mean=r(mean)
		qui gen `var'_sd=r(sd)
		qui gen std_`i'_`l'=(`var'-`var'_mean)/`var'_sd
		qui egen mean_std_`i'_`l'_t=mean( std_`i'_`l') if t1==1
		qui replace std_`i'_`l'=mean_std_`i'_`l'_t if t1==1 & std_`i'_`l'==.
		qui replace std_`i'_`l'=0 if t1==0 & std_`i'_`l'==.
		}
	local l = 0
	drop *_mean *_sd mean_std_*
	}

egen zscore_5=rowmean( std_5_1 std_5_2 std_5_3 std_5_4 std_5_5 std_5_6 std_5_7 std_5_8 std_5_9 std_5_10 std_5_11 std_5_12 std_5_13 std_5_14 std_5_15 std_5_16 std_5_17 std_5_18 std_5_19 std_5_20 std_5_21 std_5_22 std_5_23 std_5_24 std_5_25 std_5_26 std_5_27 std_5_28 std_5_29 std_5_30 std_5_31 std_5_32 std_5_33 std_5_34 std_5_35 std_5_36 std_5_37 std_5_38 std_5_39 std_5_40 std_5_41 std_5_42 std_5_43 std_5_44 std_5_45 std_5_46 std_5_47)
egen zscore_6=rowmean( std_6_1 std_6_2 std_6_3 std_6_4 std_6_5 std_6_6 std_6_7 std_6_8 std_6_9 std_6_10 std_6_11 std_6_12 std_6_13 std_6_14 std_6_15 std_6_16 std_6_17 std_6_18 std_6_19 std_6_20 std_6_21 std_6_22 std_6_23 std_6_24 std_6_25)
	
* regress 
foreach num of numlist 1 (1) 12{
	reg  zscore_`num' `indepvars', robust
	display "Hypothesis number in Table= `num'"
	estimates store tab1_09_h`num'
}

* Drop duplicates - i.e. outcomes that appear under more than 1 hypothesis within a family (Fam A has 39 unique outcomes in total, Fam B has 155 unique)
drop std_3_6 // bank_acct
drop std_4_13 std_8_15 std_5_2 std_10_11 std_6_3 std_6_8 std_6_17 std_6_24 std_12_1 std_12_2 std_12_3 // mkt_grp(x2), gift_meet, vdc, gift_say, proj_dem, vote, tarp_say, nobeatwife, leader_yth, leader_wmn

* create family zscore 
egen zscore_famA=rowmean(std_1_* std_2_* std_3_*)
egen zscore_famB=rowmean(std_4_* std_5_*  std_6_* std_7_* std_8_* std_9_* std_10_* std_11_* std_12_*)

reg  zscore_famA `indepvars', robust
	estimates store tab1_09_famA
reg  zscore_famB `indepvars', robust
	estimates store tab1_09_famB
	mata: te_2009_B = st_matrix("r(table)")[1,1], st_matrix("r(table)")[5,1], st_matrix("r(table)")[6,1], st_matrix("r(table)")[2,1]

drop std_*
	
* output	
esttab tab1_09_* using "tables/Table_1_2009.csv", cells(b(star fmt(%9.3f)) se(par fmt(%9.3f)) p(par("[" "]") fmt(%9.3f))) stats(N, fmt( %9.0f %9.2f)) style(fixed) starlevels(* .1 ** .05 *** .01) keep (t1) replace /// 
	title("Table 1. Panel A1 Medium Run Effects (2009 outcomes)") mtitles("H1 - Implementation" "H2 - Local Public Infrastructure" "H3 - Economic welfare" "H4 - Collective action"	"H5 - Inclusion"	"H6 - Systems of authority"	"H7 - Trust"	"H8 - Groups and networks"	"H9 - Information"	"H10 - Participation"	"H11 - Crime and conflict"	"H12 - Attitudes"  "Family A" "Family B") ///
		addnotes("")	
		
* keep zscores for decay model, save to merge with 2016 zscores 
preserve 
	keep id_vill zscore_*  `indepvars' 
	ren zscore_*  zscore0_*
	save "temp/temp_zscores2009.dta", replace
restore 
		

*************
/*  Decay Model */	
*************

* call up data and merge 
use "temp/temp_zscores2016.dta", clear
merge 1:1 id_vill using "temp/temp_zscores2009.dta"
 
* generate dep var 2016 - 2009, zscore1_h1  - zscore1_h1 
foreach num of numlist 1(1)12 {
	gen zscoredif_h`num' = zscore1_h`num' - zscore0_`num' 
} 

gen zscoredif_hfamA = zscore1_famA - zscore0_famA 
gen zscoredif_hfamB = zscore1_famB - zscore0_famB 

* run model 
foreach num of numlist 1 (1) 12 {
	reg  zscoredif_h`num' `indepvars', robust 
	display "Hypothesis number in Table= `num'"
	estimates store tab1_decay_`num'
}

reg  zscoredif_hfamA `indepvars', robust
	estimates store tab1_decay_famA
reg  zscoredif_hfamB `indepvars', robust
	estimates store tab1_decay_famB

* output		
	esttab tab1_decay_* using "tables/Table_1_decay.csv", cells(b(star fmt(%9.3f)) se(par fmt(%9.3f)) p(par("[" "]") fmt(%9.3f))) stats(N, fmt( %9.0f %9.2f)) style(fixed) starlevels(* .1 ** .05 *** .01) keep (t1) replace /// 
	title("Table 1. Decay Model") mtitles("H1 - Implementation" "H2 - Local Public Infrastructure" "H3 - Economic welfare" "H4 - Collective action"	"H5 - Inclusion"	"H6 - Systems of authority"	"H7 - Trust"	"H8 - Groups and networks"	"H9 - Information"	"H10 - Participation"	"H11 - Crime and conflict"	"H12 - Attitudes" "Family A" "Family B") ///
		addnotes("")	
*		* Notes: i) significance levels based on naive p-values and indicated by * p<0.10, ** p<0.05, ***p<0.01,  ii) specifications include strata for geographic ward and two balancing variables (distance to road and community size) from the original randomization; iii) robust standard errors; iv) all estimates are for hypothesis-level equally weighted mean effects indices, expressed in standard deviation units (see Kling, Liebman and Katz 2007); v) the dependent variable in column 5 is the difference in 2009 and 2006 indices, where the set of component measures varies across survey round (see Appendix Table A1 for exact panel specification); and vi) 2009 data sourced from Casey, Glennerster and Miguel (2012).							


********************************************************************************
************************************ FIGURE 2 **********************************
********************************************************************************

*Open 2009 dataset and append with 2016 data

use "data/gbf_analysis.dta", clear 
ren t t1 
append using "data/SES_analysis.dta" 
replace post=2 if post==. //Baseline (post=0), SR (post=1), LR (Post=2)
label define post 0 "Baseline" 1 "Short run" 2 "Long run"
label values post post 
save "temp/temp_panel.dta", replace 	

*Reabel variables for figure

label var bank_acct "Bank Account"
label var vdc "Village Development Committee"
label var vdp "Village Development Plan"
label var vis_wdc "Visit by WDC Member"


foreach var of varlist vdc bank_acct vdp vis_wdc{
	qui reg `var' `indepvars' if post==1, robust
	local t_sr= _b[t1]/_se[t1]
	local p_s =2*ttail(e(df_r),abs(`t_sr')) 	
	local p_sr : di %3.2f `p_s'
	
	qui reg `var' `indepvars' if post==2, robust
	local t_lr= _b[t1]/_se[t1]
	local p_l =2*ttail(e(df_r),abs(`t_lr')) 	
	local p_lr : di %3.2f `p_l'
	
	foreach time in sr lr{
	local time_lbl = upper(`"`time'"')
		if `p_`time''<0.01 {
			local sub_`time' "{it: p{subscript:`time_lbl'}} <0.01"
		}
		
		else {
			local sub_`time' "{it: p{subscript:`time_lbl'}} =`p_`time''"
		}
	}

	
	bysort t1 post: egen m_`var'=mean(`var') 
	local label : var label `var'
	label var m_`var' `"`label"'
	local title: var label m_`var' 
	
	
	twoway (bar  m_`var' t1 if post==1, hor  barw(0.8) color(ltblue) ) (scatter t1 m_`var' if post==2, m(diamond)), nodraw name(g_`var', replace) ytitle("") xtitle("") title("`title'", size(*0.8)) text(1.4 0.99 "`sub_sr'", size(.28cm)) text(1 0.99 "`sub_lr'", size(.28cm)) legend( label(1 "Short run") label(2 "Long run") rows(1)) yscale(r(0 0.5)) ylabel(none 0 "C" 1 "T", noticks nogrid) graphregion(color(white)) xscale(r(0 1))  xlabel(0(0.1)1)
	
	local glist_projimp `glist_projimp' g_`var'	

}

*Save and export figure 

grc1leg2 `glist_projimp', rows(2)
graph export "figures/fig2.png", replace


********************************************************************************
************************************ FIGURE 3 **********************************
********************************************************************************

use "temp/temp_panel.dta", clear

*Recode func_tba and func_sports from household level to village level dummies

gen f_tba= func_tba
replace f_tba=1 if func_tba>0 & func_tba!=. & post==1
replace f_tba=0 if func_tba==0 & post==1
label var f_tba "Traditional birth attendant"

gen f_sports= func_sports
replace f_sports=1 if func_sports>=0.5 & func_sports!=. & post==1 
replace f_sports=0 if func_sports<0.5 & func_sports!=.  & post==1
label var f_sports "Sports field"

save "temp/temp_panel_pgoods.dta", replace
		
*Total number of public goods
		
egen total_pgoods= rowtotal(f_psch f_phu f_well f_dryflr f_grnstr f_comcntr f_palava  f_barrie f_market f_latrine f_tba f_sports)	
bysort t1 post: egen m_total_pgoods=mean(total_pgoods)


*************
/*  Figure */	
*************
	qui reg total_pgoods `indepvars' if post==1, robust
	local t_sr= _b[t1]/_se[t1]
	local p_s =2*ttail(e(df_r),abs(`t_sr')) 	
	local p_sr : di %3.2f `p_s'
	
	qui reg total_pgoods `indepvars' if post==2, robust
	local t_lr= _b[t1]/_se[t1]
	local p_l =2*ttail(e(df_r),abs(`t_lr')) 	
	local p_lr : di %3.2f `p_l'
	
	foreach time in sr lr{
	local time_lbl = upper(`"`time'"')
		if `p_`time''<0.01 {
			local sub_`time' "{it: p{subscript:`time_lbl'}} <0.01"
		}
		
		else {
			local sub_`time' "{it: p{subscript:`time_lbl'}} =`p_`time''"
		}
	}

	


twoway (bar  m_total_pgoods t1 if post==1, hor  barw(0.8)  color(ltblue) ) ///
(scatter t1 m_total_pgoods if post==2, m(diamond)), ///
xscale(r(0 5))  xlabel(0(0.5)5) yscale(r(0 0.5)) ylabel(none 0 "C" 1 "T", noticks nogrid) graphregion(color(white))  ///
legend( label(1 "Short run") label(2 "Long run") rows(1))  ///
ytitle("") xtitle("") title("Number of public goods", size(*0.8)) text(1.4 4.5 "`sub_sr'", size(.28cm)) text(1 4.5 "`sub_lr'", size(.28cm))

graph export "figures/fig3.png", replace

	

********************************************************************************
************************************ FIGURE 4 **********************************
********************************************************************************

use "temp/temp_panel.dta", clear

***Make non-binary econ welfare variables into binary version

foreach var of varlist  tot_goods tot_newbiz tot_petty{
	bysort post: egen md_`var'= median(`var') if t1==0 //median level in control
	bysort post: egen med_`var'= max(md_`var') //fill in for post 
	gen dum_`var'=cond(`var'>=med_`var', 1, 0) //1 if greater than median level in control
	replace dum_`var'=. if `var'==. //missing
	drop med_`var' md_`var' 
}
		
*Total number of economic welfare items
		
egen total_econwelf= rowtotal(betteroff petty dum*)	
bysort t1 post: egen m_total_econwelf=mean(total_econwelf)
//out_trader and training omitted because measured differently between endlines, bank_acct dropped because in projimp 

*************
/*  Figure */	
*************

	qui reg total_econwelf `indepvars' if post==1, robust
	local t_sr= _b[t1]/_se[t1]
	local p_s =2*ttail(e(df_r),abs(`t_sr')) 	
	local p_sr : di %3.2f `p_s'
	
	qui reg total_econwelf `indepvars' if post==2, robust
	local t_lr= _b[t1]/_se[t1]
	local p_l =2*ttail(e(df_r),abs(`t_lr')) 	
	local p_lr : di %3.2f `p_l'
	
		foreach time in sr lr{
		
		local time_lbl = upper(`"`time'"')
		
		if `p_`time''<0.01 {
			local sub_`time' "{it: p{subscript:`time_lbl'}} <0.01"
		}
		
		else {
			local sub_`time' "{it: p{subscript:`time_lbl'}} =`p_`time''"
		}
	}


twoway (bar  m_total_econwelf t1 if post==1, hor  barw(0.8)  color(ltblue)) ///
(scatter t1 m_total_econwelf if post==2, m(diamond)), ///
xscale(r(0 4))  xlabel(0(0.5)4) yscale(r(0 0.5)) ylabel(none 0 "C" 1 "T", noticks nogrid) graphregion(color(white)) ///
legend( label(1 "Short run") label(2 "Long run") rows(1))  ///
ytitle("") xtitle("") title("Count of economic welfare items", size(*0.8)) text(1.4 3.8 "`sub_sr'", size(.28cm)) text(1 3.8 "`sub_lr'", size(.28cm))
graph export "figures/fig4.png", replace



	
********************************************************************************
************************************ FIGURE 5 **********************************
********************************************************************************

use "temp/temp_panel.dta", clear

**Define variable macros

local fam_a "bank_acct vdc vdp vis_lc vis_wdc days_brush f_psch f_phu f_well  f_dryflr f_grnstr f_comcntr f_palava f_barrie f_market f_latrine f_sports f_tba footunif no_bush proposal seedbank  betteroff out_trader petty tot_goods tot_newbiz tot_petty training" // family A; mean mc_score not in endline 1
local fam_b "vdc days_brush no_bush proposal commfarm commtchr mkt_grp disabled_ldr disabled_meet meet_com meet_wmn meet_yth minutes nocorrupt ms_debate ms_cons ms_demo ms_dur ms_wmn_active ms_yth_active ms_spkr ms_wmn ms_yth ms_vote chf_age  trust_lc_chf ms_nochief osusu  trust_cg trust_chf trust_lc trust_ngo trust_out trust_own fishcoop mbr_pta mbr_rel mbr_sav mbr_seed mbr_soc mbr_wom mbr_yth vis_lc vis_wdc disp_ind vis_pc vdp stand_lc stand_pc stand_sc stand_wdc no_conflict no_fight no_theft no_witch vh_fem vh_youth"  //family B; techscore policyscore expscore, winner not in endline 
	

*Harmonize analogous variables between 2009 and 2016

gen f_tba= func_tba
replace f_tba=1 if func_tba>0 & func_tba!=. & inlist(post, 0, 1) 
replace f_tba=0 if func_tba==0 & inlist(post, 0, 1)
 
gen f_sports= func_sports
replace f_sports=1 if func_sports>=0.5 & func_sports!=. & inlist(post, 0, 1) 
replace f_sports=0 if func_sports<0.5 & func_sports!=.  & inlist(post, 0, 1)
		
recode no_bush (1=0) (2=.33) (3=.66) (4=1) if post==2 
replace no_bush=0 if no_bush<1 & no_bush !=.

qui summarize out_trader if post==2 & t1==0, detail 
local con_med = r(p50)
replace out_trader= 0 if  out_trader< `con_med' & out_trader!=. & post ==2 
replace out_trader= 1 if  out_trader>= `con_med' & out_trader!=. & post ==2 

qui summarize training if post==2 & t1==0, detail 
local con_med = r(p50)
replace training= 0 if  training< `con_med' & training!=. & post ==2 
replace training= 1 if  training>= `con_med' & training!=. & post ==2 
replace training= 1 if  training> 0 & training!=. & post ==1

replace ms_debate = debate if inlist(post, 0, 1) 
replace ms_debate=1 if ms_debate>=0.5 & ms_debate!=.

replace ms_a16=0 if inrange(ms_a16, 1, 3)
replace ms_a16=1 if ms_a16==4
replace ms_b13=0 if inrange(ms_b13, 1, 3)
replace ms_b13=1 if ms_b13==4
replace ms_cons = (ms_a16 + ms_b13)/2 if post==2
replace ms_cons = dem_cards if inlist(post, 0, 1) 
replace ms_cons=0 if ms_cons<0.5 & ms_cons!=.
replace ms_cons=1 if ms_cons>=0.5 & ms_cons!=.

replace ms_demo= democ if inlist(post, 0, 1)

replace ms_dur= duration if inlist(post, 0, 1)

replace ms_wmn_active= role_wmn if inlist(post, 0, 1) 

replace ms_yth_active= role_yth if inlist(post, 0, 1) 

replace ms_spkr= spkr_tot if inlist(post, 0, 1)

replace ms_wmn= spkr_wmn if inlist(post, 0, 1)

replace ms_yth= spkr_yth if inlist(post, 0, 1)

replace ms_vote= vote if inlist(post, 0, 1)
replace ms_vote=0 if ms_vote<0.5 & ms_vote!=. & inlist(post, 0, 1)
replace ms_vote=1 if ms_vote>=0.5 & ms_vote!=. & inlist(post, 0, 1)

replace chf_age= rtarp_public if inlist(post, 0, 1) 
replace chf_age=0 if chf_age<0.5 & chf_age!=. & inlist(post, 0, 1)
replace chf_age=1 if chf_age>=0.5 & chf_age!=. & inlist(post, 0, 1) 
replace chf_age=1 if inrange(chf_age, -34, 0)& post==2 
replace chf_age=0 if inrange(chf_age, -99, -35)& post==2

replace trust_lc_chf=0 if trust_lc_chf<0.5 & trust_lc_chf!=. & inlist(post, 0, 1)
replace trust_lc_chf=1 if trust_lc_chf>=0.5 & trust_lc_chf!=. & inlist(post, 0, 1) 
replace trust_lc_chf =0 if trust_lc_chf<0 & trust_lc_chf !=. & post==2

replace ms_nochief= chf_consult if inlist(post, 0, 1)
replace ms_nochief=1 if ms_nochief>=0.5 & post==2 & ms_nochief!=.

qui summarize osusu if post==2 & t1==0, detail 
local con_med = r(p50)
replace osusu= 0 if  osusu< `con_med' & osusu!=. & post ==2 
replace osusu= 1 if  osusu>= `con_med' & osusu!=. & post ==2 
replace osusu=0 if osusu<0.5 & osusu!=. & inlist(post, 0, 1)
replace osusu=1 if osusu>=0.5 & osusu!=. & inlist(post, 0, 1) 

foreach var of varlist trust_cg trust_chf trust_lc trust_ngo trust_out trust_own{
 replace `var'=0 if `var'<0.5 & `var'!=. & inlist(post, 0, 1)
replace `var'=1 if `var'>=0.5 & `var'!=. & inlist(post, 0, 1) 
}

replace disp_ind=0 if disp_ind<0.5 & disp_ind!=.
replace disp_ind=1 if disp_ind>=0.5 & disp_ind!=.

replace mbr_yth= mbr_youth if inlist(post, 0, 1)

foreach var of varlist  mbr_pta mbr_rel mbr_sav mbr_seed mbr_soc mbr_wom mbr_yth no_conflict no_fight no_theft no_witch{
	qui summarize `var' if post==2 & t1==0, detail 
	local con_med = r(p50)
	gen dum_`var'=`var'
	replace dum_`var'= 0 if  `var'< `con_med' & `var'!=. & post ==2 
	replace dum_`var'= 1 if  `var'>= `con_med' & `var'!=. & post ==2 
	 replace dum_`var'=0 if `var'<0.5 & `var'!=. & inlist(post, 0, 1)
	replace dum_`var'=1 if `var'>=0.5 & `var'!=. & inlist(post, 0, 1) 
	drop `var'
	rename dum_`var' `var'
}


foreach var of varlist days_brush tot_goods tot_newbiz tot_petty meet_com meet_wmn meet_yth ms_demo ms_dur ms_wmn_active ms_yth_active ms_spkr ms_wmn ms_yth {
	bysort post: egen md_`var'= median(`var') if t1==0 //median level in control
	bysort post: egen med_`var'= max(md_`var') //fill in for post 

	gen dum_`var'=`var'
	replace dum_`var'= 0 if  `var'< med_`var' & `var'!=.
	replace dum_`var'= 1 if  `var'>= med_`var' & `var'!=. 
	drop m*_`var' `var'
	rename dum_`var' `var'
}



*************
/*  Figure */	
*************

foreach fam in a b{
	*Number of items in each family for each village 	
	egen fam_`fam'= rowtotal(`fam_`fam'')

	*Median in each family 
	summarize fam_`fam' if post==1 & t1==1, detail 
	local med_sr_t = r(p50)
	
	summarize fam_`fam' if post==1 & t1==0, detail 
	local med_sr_c = r(p50)
	
	summarize fam_`fam' if post==2 & t1==1, detail 
	local med_lr_t = r(p50)
	
	summarize fam_`fam' if post==2 & t1==0, detail 
	local med_lr_c = r(p50)
	

	*Kolmogorov –Smirnov equality-of-distributions test
	ksmirnov fam_`fam' if post==1, by(t1) exact
	ksmirnov fam_`fam' if post==2, by(t1) exact
	
	
	
	*Draw kernel density plots
	twoway (kdensity fam_`fam'  if t1==0 & post==1,  yscale(r(0 0.15)) ylabel(0(0.05)0.15) ytitle("Kernel density") xtitle("") xline(`med_sr_c', lcolor(navy) lpattern(dash))) (kdensity fam_`fam'  if t1==1 & post==1, lwidth(thick) yscale(r(0 0.15))  ylabel(0(0.05)0.15) ytitle("Kernel density") xtitle("") xline(`med_sr_t', lcolor(maroon) lpattern(dash) lwidth(thick))),  name(sr_`fam', replace) title("Short run") legend(order(1 "Control" 2 "Treated"))

	twoway (kdensity fam_`fam'  if t1==0 & post==2, yscale(r(0 0.15))  ylabel(0(0.05)0.15) ytitle("Kernel density") xtitle("") xline(`med_lr_c',  lcolor(navy) lpattern(dash))) (kdensity fam_`fam'  if t1==1 & post==2, lwidth(thick) yscale(r(0 0.15))  ylabel(0(0.05)0.15) ytitle("Kernel density") xtitle("") xline(`med_lr_t', lcolor(maroon) lpattern(dash) lwidth(thick))),  name(lr_`fam', replace)title("Long run") legend(order(1 "Control" 2 "Treated"))
	}
	

	
	
*Save and export figures
grc1leg2 sr_a lr_a, ytol1title title("Panel A: Infrastructural hardware family") name(a, replace) loff
graph export "figures/fig5_a.png", replace

grc1leg2 sr_b lr_b, ytol1title title("Panel B: Institutional software family") name(b, replace)
graph export "figures/fig5_b.png", replace


*Save family A and family B counts
save "temp/temp_panel_family.dta", replace

	

	
********************************************************************************
************************************ FIGURE 6 **********************************
********************************************************************************

*************
/*  Figure */	
*************

use "data/public_expert_data.dta", clear
drop if coauthor == 1 // removing coauthors 

*re-order by expert so resuls apppear monitonic for Fam A
recode type (2=1) (1=2)
recode type (3=4) (4=3)

* Export scalars from 2016 regressions saved in mata matrices
mata : 
a_te = te_2016_A[1,1]
st_numscalar("a_te", a_te)
a_upper = te_2016_A[1,2]
st_numscalar("a_upper", a_upper)
a_lower = te_2016_A[1,3]
st_numscalar("a_lower", a_lower)

b_te = te_2016_B[1,1]
st_numscalar("b_te", b_te)
b_upper = te_2016_B[1,2]
st_numscalar("b_upper", b_upper)
b_lower = te_2016_B[1,3]
st_numscalar("b_lower", b_lower)
end





* Panel A: Long Run Infrastructure Change
preserve
	la var famA "Expected Infrastructure Change"
	stripplot famA, cumul cumprob  bar(mean(msize(large))) ///
	centre over(type)  mcolor(dkgreen)  ///
	xlabel(2 `" "Policymakers" "Sierra Leone" "' ///
		   1  `" "Students" "Sierra Leone" "' ///
		   4 `" "Policymakers" "OECD" "' ///
		   3 `" "Students" "OECD" "' ///
		   5 `" "Faculty:" "economics and" "political science" "' , ///
		   labsize(vsmall) valuelabel) ///
    yscale(range(0 0.5)) ylabel(0(0.1)0.5) ///
	vertical xsize(4) xtitle("")  graphregion(color(white)) ///
	name("fig6_panel_a", replace) ///
	yline(`=a_te', lcolor(lblue)) ///
	yline(`=a_upper', lpattern(dash)) ///
	yline(`=a_lower', lpattern(dash))
restore 


* Panel B: Long Run Institutional Change
preserve
	la var famB "Expected Institutional Change"
	stripplot famB, cumul cumprob  bar(mean(msize(large))) ///
	centre over(type) mcolor(dkgreen) ///
	xlabel(2 `" "Policymakers" "Sierra Leone" "' ///
		   1  `" "Students" "Sierra Leone" "' ///
		   3 `" "Students" "OECD" "' ///
		   4 `" "Policymakers" "OECD" "' ///
		   5 `" "Faculty:" "economics and" "political science" "' , ///
		   labsize(vsmall) valuelabel) ///
    yscale(range(0 0.5)) ylabel(0(0.1)0.5) ///
	vertical xsize(4) xtitle("")  graphregion(color(white)) ///
	name("fig6_panel_b", replace) ///
	yline(`=b_te', lcolor(lblue)) ///
	yline(`=b_upper', lpattern(dash)) ///
	yline(`=b_lower', lpattern(dash))
restore 

* Panel C: Project Challenge
preserve
	la var CDDc_SQ "Expected Proposals Submitted"
	stripplot CDDc_SQ, cumul cumprob  bar(mean(msize(large))) ///
	centre over(type)  mcolor(dkgreen)  ///
	xlabel(2 `" "Policymakers" "Sierra Leone" "' ///
		   1  `" "Students" "Sierra Leone" "' ///
		   4 `" "Policymakers" "OECD" "' ///
		   3 `" "Students" "OECD" "' ///
		   5 `" "Faculty:" "economics and" "political science" "' , ///
		   labsize(vsmall) valuelabel) ///
    yscale(range(0 100)) ylabel(0(20)100) ///
	vertical xsize(4) xtitle("")  graphregion(color(white)) ///
	name("fig6_panel_c", replace) ///
	yline(98, lcolor (lblue))
restore 

* Save All
gr export "figures/fig6_panela.png", ///
	name(fig6_panel_a) replace
gr export "figures/fig6_panelb.png", ///
	name(fig6_panel_b) replace
gr export "figures/fig6_panelc.png", ///
	name(fig6_panel_c) replace
 
*************
/*  Inference */	
*************
 
use "data/public_expert_data.dta", clear
local groups "policy_sl students_sl policy_oecd students_oecd faculty coauthors"

* Also interested in coauthors here
replace type = 6 if coauthor == 1
replace CDDc_SQ=. if coauthor == 1 // PIs saw this outcome before forecasting, so results are dropped

forvalues i = 1/6{
	**********
	* Hardware
	**********
	
	* Sum, get info
	qui sum famA if type == `i'
	mata: A_`i' = st_numscalar("r(N)"), st_numscalar("r(mean)"), st_numscalar("r(sd)")
	* Difference, SE
	mata: A_guess_`i' = A_`i'[1,1], te_2016_A[1,1] - A_`i'[1,2], sqrt(((A_`i'[1,3]^2)/A_`i'[1,1]) + te_2016_A[1,4]^2)
	* T-stat
	mata: A_guess_`i' = A_guess_`i', abs(A_guess_`i'[1,2]/A_guess_`i'[1,3])
	* P-value
	mata: A_guess_`i' = A_guess_`i', 2*(1-normal(A_guess_`i'[1,4]))
	
	**********
	* Software
	**********
	qui sum famB if type == `i'
	mata: B_`i' = st_numscalar("r(N)"), st_numscalar("r(mean)"), st_numscalar("r(sd)")
	* Difference, SE
	mata: B_guess_`i' = B_`i'[1,1], te_2016_B[1,1] - B_`i'[1,2], sqrt(((B_`i'[1,3]^2)/B_`i'[1,1]) + te_2016_B[1,4]^2)
	* T-stat
	mata: B_guess_`i' = B_guess_`i', abs(B_guess_`i'[1,2]/B_guess_`i'[1,3])
	* P-value
	mata: B_guess_`i' = B_guess_`i', 2*(1-normal(B_guess_`i'[1,4]))
	
	**********
	* Takeup
	**********
	mata: takeup = 98.3
	if `i'!=6{
		qui ttest CDDc_SQ == 98.3 if type == `i'
		mata: C_guess_`i' =  st_numscalar("r(N_1)") , takeup[1,1] - st_numscalar("r(mu_1)"), st_numscalar("r(sd_1)"), st_numscalar("r(t)"), st_numscalar("r(p)")
	}
	 
} 


///// intext footnote ////

*Page 18- "The co-authors of this paper predicted more pessimistic long run outcomes with an average of 0.008 (0.017) for hardware outcomes and 0.147 (SD 0.144) software outcomes."

su famA famB if coauthor==1

**********
* Pooled Infrastructure Forecast vs. 2016 Estimated Effect
**********

* Pooled together, the experts predicted a long-run treatment effect of 0.219 standard deviation units (standard error 0.127), which is statistically indistinguishable from the estimated effect (of 0.204). 

sum famA 
mata: A = st_numscalar("r(N)"), st_numscalar("r(mean)"), st_numscalar("r(sd)")
* Difference, SE
mata: A_guess= A[1,1], te_2016_A[1,1] - A[1,2], sqrt(((A[1,3]^2)/A[1,1]) + te_2016_A[1,2]^2)
* T-stat
mata: A_guess = A_guess, abs(A_guess[1,2]/A_guess[1,3])
* P-value
mata: A_guess = A_guess, 2*(1-normal(A_guess[1,4]))

mata: A_guess

**********
* Pooled Institutions Forecast vs. 2009 Estimated Effect
**********

* Pooled together, the experts predicted a long-run effect that significantly exceeds what was estimated in the short-run (0.098 predicted by experts, compared to 0.028 units in Casey, Glennerster and Miguel 2012)

sum famB
mata: A = st_numscalar("r(N)"), st_numscalar("r(mean)"), st_numscalar("r(sd)")
mata: B = st_numscalar("r(N)"), st_numscalar("r(mean)"), st_numscalar("r(sd)")
* Difference, SE
mata: B_guess = B[1,1], te_2009_B[1,1] - B[1,2], sqrt(((B[1,3]^2)/B[1,1]) + te_2009_B[1,4]^2)
* T-stat
mata: B_guess = B_guess, abs(B_guess[1,2]/B_guess[1,3])
* P-value
mata: B_guess = B_guess, 2*(1-normal(B_guess[1,4]))
	
mata: B_guess

*, and remains statistically different from zero even when limited to the subgroup of experts who were primed with information on the short-run results.  

ttest CDDc_SQ==0 if version == 2


* Tables for inspection
* Hardware Outcomes
mata: A_table = A_guess_1 \ A_guess_2 \ A_guess_3 \ A_guess_4 \ A_guess_5 \ A_guess_6

mata: st_matrix("A_table", A_table)
preserve
	quietly{
		clear
		svmat A_table
		ren A_table1 N
		ren A_table2 Est_Minus_Fore
		ren A_table3 SE
		ren A_table4 t
		ren A_table5 p
		gen type = ""
		forvalues i = 1/6{
			local name : word `i' of `groups'
			replace type = "`name'" if _n == `i'
		}
		
		order type
	}
	
	di "Long-run Infrastructure Change"
	list
restore


* Software Outcomes
mata: B_table = B_guess_1 \ B_guess_2 \ B_guess_3 \ B_guess_4 \ B_guess_5 \ B_guess_6

mata: st_matrix("B_table", B_table)
preserve
	quietly{
		clear
		svmat B_table
		ren B_table1 N
		ren B_table2 Est_Minus_Fore
		ren B_table3 SE
		ren B_table4 t
		ren B_table5 p
		gen type = ""
		forvalues i = 1/6{
			local name : word `i' of `groups'
			replace type = "`name'" if _n == `i'
		}
		
		order type
		}
	
	di "Long-run Institutional Change"
	list
restore

* Uptake
mata: C_table = C_guess_1 \ C_guess_2 \ C_guess_3 \ C_guess_4 \ C_guess_5

mata: st_matrix("C_table", C_table)
preserve
	quietly{
		clear
		svmat C_table
		ren C_table1 N
		ren C_table2 Est_Minus_Fore
		ren C_table3 SE
		ren C_table4 t
		ren C_table5 p
		gen type = ""
		forvalues i = 1/5{
			local name : word `i' of `groups'
			replace type = "`name'" if _n == `i'
		}
		
		order type
	}
	
	di "Entry Into the Grants Competition"
	list
restore
 

********************************************************************************
************************************ TABLE 2 ***********************************
********************************************************************************

use "data/SES_analysis.dta", clear

mata: mata clear

local vars_h13 "task_eb law_eb seekwestern seekwestern_eb  air_eb days_eb get_eb hotline_eb protect_eb salt_eb chlorine_eb spread_eb sympt_eb"

local indepvars "t1 tothhs road ward*" 

* Calculating z-scores
foreach var of varlist  `vars_h13' {
		qui sum `var' if t1==0
		qui gen `var'_mean=r(mean)
		
		* Store mean in mata
		scalar mean_`var' = r(mean)
		mata: mean_`var' = st_numscalar(" mean_`var'")
		
		qui gen `var'_sd=r(sd)
		qui gen std_`var'=(`var'-`var'_mean)/`var'_sd
		* impute missing values
		egen mean_std_`var'_t=mean( std_`var') if t1==1
		replace std_`var'=mean_std_`var'_t if t1==1 & std_`var'==.
		replace std_`var'=0 if t1==0 & std_`var'==.
		local zscore_string_13="`zscore_string_13'" + " std_`var'"
		di "`zscore_string_13'"
		}
	
* Construct mean index, store the average
egen zscore_all=rowmean(`zscore_string_13')
egen zscore_know=rowmean(std_air_eb std_days_eb std_get_eb std_hotline_eb std_protect_eb std_salt_eb std_chlorine_eb std_spread_eb std_sympt_eb)
egen zscore_res= rowmean(std_task_eb std_law_eb std_seekwestern std_seekwestern_eb)

sum zscore_all if t1==0
scalar mean_zscore_all = r(mean)
sum zscore_know if t1==0
scalar mean_zscore_know = r(mean)
sum zscore_res if t1==0
scalar mean_zscore_res = r(mean)

mata: mean_zscore_all = st_numscalar("mean_zscore_all") 
mata: mean_zscore_know= st_numscalar("mean_zscore_know") 
mata: mean_zscore_res= st_numscalar("mean_zscore_res") 
	
* Regress each on treatment and balancing, store results
local reg_eb = "zscore_all"+ " `vars_h13'" 
local regs `reg_eb' zscore_know zscore_res
foreach var of varlist  `regs'{
	qui reg `var' `indepvars', r
	mata: te_`var' = st_matrix("r(table)")[1,1], st_matrix("r(table)")[2,1], st_matrix("r(table)")[4,1]
}


* Concatenate everything
local table_eb = "zscore_all" + " `vars_h13'"
local table_vars `table_eb' zscore_know zscore_res
foreach var of varlist `table_vars'{
	*di "This is a `var'"
	mata: `var' = mean_`var', te_`var'
	
	* First variable defines the matrix
	if `var'==zscore_all{
		mata: A = (zscore_all)
	}
	
	* Everything else is appended
	else{
		mata: A = (A \ `var')
	}	
} 

* Make table
mata: st_matrix("A", A)
preserve
	clear
	svmat A
	ren A1 Mean_Controls
	ren A2 Treatment_Effect
	ren A3 Standard_Error
	ren A4 p_value
	
	gen varname = ""
	local loopto : word count `table_vars'
	forvalues i = 1/`loopto'{
		local outcome : word `i' of `table_vars'
		replace varname = "`outcome'" if _n == `i'
	}
	
	
	outsheet using "tables/Table_2.csv", comma replace
restore 



********************************************************************************
*********************************** TABLE A1 ***********************************
********************************************************************************
eststo clear

*************
/*  2016 Outcomes */	
*************

use "data/SES_analysis.dta", clear

preserve 

	* Rename SVA variables in H5 to make consistent with 2009 name for merge
	ren  (ms_debate ms_cons ms_demo    ms_dur    ms_wmn_active ms_yth_active   ms_spkr ms_wmn ms_yth ms_vote) (debate dem_cards democ duration  role_wmn role_yth spkr_tot spkr_wmn spkr_yth  vote)
	ren  chf_age rtarp_public 
	ren  ms_nochief chf_consult
	ren  mbr_yth mbr_youth

	* Macros 
	local vars1_h1 "bank_acct vdc vdp vis_lc vis_wdc" 
	local vars1_h2 "days_brush f_psch f_phu f_well  f_dryflr f_grnstr f_comcntr f_palava f_barrie f_market f_latrine func_sports func_tba footunif no_bush proposal seedbank"
	local vars1_h3 "bank_acct betteroff out_trader petty tot_goods tot_newbiz tot_petty training"
	local vars1_h4 "vdc days_brush no_bush proposal commfarm commtchr mkt_grp"
	local vars1_h5 "disabled_ldr disabled_meet meet_com meet_wmn meet_yth minutes nocorrupt   debate dem_cards  democ duration  role_wmn role_yth spkr_tot spkr_wmn spkr_yth vote"
	local vars1_h6 "rtarp_public  trust_lc_chf  chf_consult vote"
	local vars1_h7 "mkt_grp osusu trust_cg trust_chf trust_lc trust_ngo trust_out trust_own"
	local vars1_h8 "mkt_grp osusu fishcoop mbr_pta mbr_rel mbr_sav mbr_seed mbr_soc mbr_wom mbr_youth"
	local vars1_h9 "vis_lc vis_wdc disp_ind vis_pc"
	local vars1_h10 "vdc vdp stand_lc stand_pc stand_sc stand_wdc"
	local vars1_h11 "no_conflict no_fight no_theft no_witch"
	local vars1_h12 "vh_fem vh_youth"

	br `vars1_h4' `vars1_h5' `vars1_h6' `vars1_h7' `vars1_h8' `vars1_h9' `vars1_h10' `vars1_h11' `vars1_h12'
	gen endline = 1

	foreach num of numlist 1 (1) 12{
	local i = `num'
	foreach var of varlist  `vars1_h`i'' {
		local l = `l' + 1
		qui sum `var' if t1==0
		qui gen `var'_mean=r(mean)
		qui gen `var'_sd=r(sd)
		qui gen std_`i'_`l'=(`var'-`var'_mean)/`var'_sd
		* impute missing values
		egen mean_std_`i'_`l'_t=mean( std_`i'_`l') if t1==1
		replace std_`i'_`l'=mean_std_`i'_`l'_t if t1==1 & std_`i'_`l'==.
		replace std_`i'_`l'=0 if t1==0 & std_`i'_`l'==.
		local pzscore_string_`i'="`pzscore_string_`i''" + " std_`i'_`l'"
			}
	egen pzscore_h`i'=rowmean(`pzscore_string_`i'')
	local pzscore_string_`i'=""
	local l = 0
	drop *_mean *_sd mean_std_* 
	}

	foreach num of numlist 1 (1) 12 {
	reg  pzscore_h`num' `indepvars', robust
	display "Hypothesis number in Table= `num'"
	estimates store tabA1col1_p`num'
	}

	* Drop EXACT PANEL duplicates for family-level estimates (i.e. outcomes that appear under multiple hypos within a family)
	drop std_3_1 // bank_acct in H1 and H3
	drop std_10_1 //vdc in H4 and H10
	drop std_7_1 std_8_1 // mkt_grp in H4, H7 and H8
	drop std_6_4 //ms_vote
	drop std_8_2 // osusu in H7 and H8

	egen pzscore_famA=rowmean(std_1_* std_2_* std_3_*)
	egen pzscore_famB=rowmean(std_4_* std_5_* std_6_*  std_7_*  std_8_* std_9_* std_10_*  std_11_*  std_12_*) 

	reg  pzscore_famA `indepvars', robust
		estimates store tabA1col1_pfamA
	reg  pzscore_famB `indepvars', robust
		estimates store tabA1col1_pfamB
		
	drop std_*

	* Output
	esttab tabA1col1_p* using "tables/Table_A1_2016.csv", cells(b(star fmt(%9.3f)) se(par fmt(%9.3f)) p(par("[" "]") fmt(%9.3f))) stats(N, fmt( %9.0f %9.2f)) style(fixed) starlevels(* .1 ** .05 *** .01) keep (t1) replace /// 
	title("Appendix Table A1: Long Run Effects Exact Panel Outcomes") mtitles("H1 - Implementation" "H2 - Local Public Infrastructure" "H3 - Economic welfare" "H4 - Collective action"	"H5 - Inclusion" "H6 - Local authority"	"H7 - Trust"	"H8 - Groups and networks"	"H9 - Access to Information"	"H10 - Participation in governance" "H11 - Crime and conflict" "H12 - Political and social attitudes" "Family A" "Family B") ///
		addnotes("Notes: i) significance levels (based on naïve p-values) indicated by * p < 0.10, ** p <0.05, *** p < 0.01"	///
			"ii) specifications include strata for geographic ward and two balancing variables (distance to road and community size) from the randomization iii) robust standard errors")

	* Save for decay model
	keep id_vill pzscore_* `indepvars' 
	ren pzscore_* pzscore1_* 
	save "temp/temp_panel2016.dta", replace 

restore

*************
/*  2009 Outcomes */	
*************

use "data/gbf_analysis.dta", clear
keep if post==1
gen endline=0
ren t t1

foreach num of numlist 1 (1) 12 {
	local i = `num'
	foreach var of varlist  `vars1_h`i'' {
		local l = `l' + 1
		qui sum `var' if t1==0
		qui gen `var'_mean=r(mean)
		qui gen `var'_sd=r(sd)
		qui gen std_`i'_`l'=(`var'-`var'_mean)/`var'_sd
		* impute missing values
		egen mean_std_`i'_`l'_t=mean( std_`i'_`l') if t1==1
		replace std_`i'_`l'=mean_std_`i'_`l'_t if t1==1 & std_`i'_`l'==.
		replace std_`i'_`l'=0 if t1==0 & std_`i'_`l'==.
		local p9zscore_string_`i'="`p9zscore_string_`i''" + " std_`i'_`l'"
			}
	egen p9zscore_h`i'=rowmean(`p9zscore_string_`i'')
	local p9zscore_string_`i'=""
	local l = 0
	drop *_mean *_sd mean_std_*
	}

	foreach num of numlist 1 (1) 12 {
	reg  p9zscore_h`num' `indepvars', robust
	display "Hypothesis number in Table= `num'"
	estimates store tabA1col1_p09`num'
}

* Drop EXACT PANEL duplicates for family-level estimates (i.e. outcomes that appear under multiple hypos within a family)
drop std_3_1 //bank_acct in H1 and H3
drop std_10_1 //vdc in H4 and H10
drop std_7_1 std_8_1 //mkt_grp in H4, H7 and H8

egen p9zscore_famA=rowmean(std_1_* std_2_* std_3_*)
egen p9zscore_famB=rowmean(std_4_* std_5_*           std_8_* std_9_* std_10_*       std_12_*)

reg  p9zscore_famA `indepvars', robust
	estimates store tabA1col1_p09famA
reg  p9zscore_famB `indepvars', robust
	estimates store tabA1col1_p09famB
	
drop std_*

* output
esttab tabA1col1_p09* using "tables/Table_A1_2009.csv", cells(b(star fmt(%9.3f)) se(par fmt(%9.3f)) p(par("[" "]") fmt(%9.3f))) stats(N, fmt( %9.0f %9.2f)) style(fixed) starlevels(* .1 ** .05 *** .01) keep (t1) replace /// 
	title("Table A1. Robustness Robustness Medium Run Effects (2009 outcomes), Exact Panel Outcomes") mtitles("H1 - Project Implementation" "H2 - Local public goods" "H3 - Economic welfare" "H4 - Collective action"	"H5 - Inclusion"	"H6 - Local authority"  "H7 - Trust"	"H8 - Groups and networks"	"H9 - Access to information"	"H10 - Participation in governance" "H11 - Crime and conflict" "H12 - Political and social attitudes" "Family A" "Family B") ///
		addnotes("Notes: i) significance levels (based on naïve p-values) indicated by * p < 0.10, ** p <0.05, *** p < 0.01")	
		
* Save for decay model
	keep id_vill p9zscore_* `indepvars' 
	ren p9zscore_* pzscore0_* 
	save "temp/temp_panel2009.dta", replace 	

	
	
*************
/*  Decay Model */	
*************
* call up data and merge 
use "temp/temp_panel2016.dta", clear
merge 1:1 id_vill using "temp/temp_panel2009.dta"
 
* generate dep var 2016 - 2009, zscore1_h1  - zscore1_h1 
foreach num of numlist 1(1)12 {
	gen pzscoredif_h`num' = pzscore1_h`num' - pzscore0_h`num' 
} 

gen pzscoredif_hfamA = pzscore1_famA - pzscore0_famA 
gen pzscoredif_hfamB = pzscore1_famB - pzscore0_famB 

* run model 
foreach num of numlist 1 (1) 12 {
	reg  pzscoredif_h`num' `indepvars', robust 
	display "Hypothesis number in Table= `num'"
	estimates store tabA1_decay_`num'
}

reg  pzscoredif_hfamA `indepvars', robust
	estimates store tabA1_decay_famA
reg  pzscoredif_hfamB `indepvars', robust
	estimates store tabA1_decay_famB

* Output		
esttab tabA1_decay_* using "tables/Table_A1_decay.csv", cells(b(star fmt(%9.3f)) se(par fmt(%9.3f)) p(par("[" "]") fmt(%9.3f))) stats(N, fmt( %9.0f %9.2f)) style(fixed) starlevels(* .1 ** .05 *** .01) keep (t1) replace /// 
title("Table A1. Decay Model") mtitles("H1 - Implementation" "H2 - Local Public Infrastructure" "H3 - Economic welfare" "H4 - Collective action"	"H5 - Inclusion"	"H6 - Systems of authority"	"H7 - Trust"	"H8 - Groups and networks"	"H9 - Information"	"H10 - Participation"	"H11 - Crime and conflict"	"H12 - Attitudes" "Family A" "Family B") ///
	addnotes("Notes: i) significance levels (based on naïve p-values) indicated by * p < 0.10, ** p <0.05, *** p < 0.01")	
	
	
	
********************************************************************************
*********************************** TABLE A3 ***********************************
********************************************************************************
use "data/gbf_analysis.dta", clear

* Unit of obs = village (this doesn't change values)
collapse (mean) t tothhs war yrseduc road slave elf_ea chief bombali ward_*, by(id_vill)
save "temp/temp_gbf_hetero.dta", replace

* Merge into zscores
merge 1:1 id_vill using "temp/temp_zscores2016.dta", keepusing(zscore1_famA zscore1_famB t1)
corr t1 t

* Interaction terms	
foreach var of varlist tothhs war yrsedu road slave bombali elf_ea chief{
	gen `var'_t=`var'*t
	}

* Regressions	
foreach x in A B{
reg zscore1_fam`x' t1 tothhs war yrseduc road slave elf_ea chief tothhs_t war_t yrseduc_t road_t slave_t bombali_t elf_ea_t chief_t ward_*, robust
estimates store appl_`x'_hetero
test tothhs_t war_t yrseduc_t road_t slave_t bombali_t elf_ea_t chief_t
estadd scalar F_p = r(p)
test tothhs_t war_t yrseduc_t road_t slave_t elf_ea_t chief_t
estadd scalar F_p_2 = r(p)
	}

esttab appl_* using "tables/Table_A3.csv", cells(b(star fmt(%9.3f)) se(par fmt(%9.3f))) stats(N F_p F_p_2, fmt( %9.0f %9.2f)) style(fixed) starlevels(* .1 * .05 ** .01) indicate(ward_*) replace

estimates drop _all



********************************************************************************
*********************************** TABLE A4 ***********************************
********************************************************************************
use "data/SES_analysis.dta", clear

mata: mata clear

local sca_outcomes "ms_debate ms_cons ms_demo ms_dur ms_wmn_active ms_yth_active ms_spkr ms_wmn ms_yth ms_vote ms_nochief" // ms_wmn_imp ms_yth_imp"

* Calculating z-scores
foreach var of varlist  `sca_outcomes' {
		qui sum `var' if t1==0
		qui gen `var'_mean=r(mean)
		
		* Store mean in mata
		scalar mean_`var' = r(mean)
		mata: mean_`var' = st_numscalar(" mean_`var'")
		
		qui gen `var'_sd=r(sd)
		qui gen std_`var'=(`var'-`var'_mean)/`var'_sd
		
		* impute missing values
		egen mean_std_`var'_t=mean( std_`var') if t1==1
		replace std_`var'=mean_std_`var'_t if t1==1 & std_`var'==.
		replace std_`var'=0 if t1==0 & std_`var'==.
		local zscore_string_sca="`zscore_string_sca'" + " std_`var'"
		di "`zscore_string_sca'"
		}
	
* Construct mean index, store the average
egen zscore_sca=rowmean(`zscore_string_sca')
sum zscore_sca if t1==0
scalar mean_zscore_sca = r(mean)
mata: mean_zscore_sca = st_numscalar("mean_zscore_sca")
mata: mean_zscore_sca
	
* Regress each on treatment and balancing, store results
local reg_sca = "zscore_sca" + " `sca_outcomes'"
foreach var of varlist  `reg_sca'{
	qui reg `var' `indepvars', r
	scalar n = e(N) 
	mata: `var'_N = st_numscalar("e(N)")
	mata: te_`var' = st_matrix("r(table)")[1,1], st_matrix("r(table)")[2,1], st_matrix("r(table)")[4,1], `var'_N
}

* Concatenate everything
local table_vars = "zscore_sca" + " `sca_outcomes'"
foreach var of varlist `table_vars'{
	mata: `var' = mean_`var', te_`var'
	
	* First variable defines the matrix
	if `var'==zscore_sca{
		mata: A = (zscore_sca)
	}
	
	* Everything else is appended
	else{
		mata: A = (A \ `var')
	}	
} 

* Make table
mata: st_matrix("A", A)
preserve
	clear
	svmat A
	ren A1 Mean_Controls
	ren A2 Treatment_Effect
	ren A3 Standard_Error
	ren A4 Naive_p_value
	ren A5 N
	
	gen varname = ""
	local loopto : word count `table_vars'
	forvalues i = 1/`loopto'{
		local outcome : word `i' of `table_vars'
		replace varname = "`outcome'" if _n == `i'
	}
	
	order varname
	
	outsheet using "tables/Table_A4.csv", comma replace
restore 



********************************************************************************
*********************************** TABLE A5 ***********************************
********************************************************************************

* Lots of outcomes here, will just need some cross-checking to make sure that 
* the same variables do not enter more than once. 

use "data/SES_analysis.dta", clear

* Versions of macros with dropping duplicates
local indepvars "t1 tothhs road ward*" 

local uvars_h1 "bank_acct mean_mc_score vdc vdp vis_lc vis_wdc" 
local uvars_h2 "days_brush f_barrie f_comcntr f_dryflr f_grnstr f_latrine f_market f_palava f_phu f_psch f_well footunif func_sports func_tba no_bush proposal seedbank "
local uvars_h3 "betteroff out_trader petty tot_goods tot_newbiz tot_petty training"
local uvars_h4 "commfarm commtchr expscore mkt_grp policyscore techscore winner"
local uvars_h5 "disabled_ldr disabled_meet meet_com meet_wmn meet_yth minutes ms_cons ms_demo ms_dur ms_spkr ms_vote ms_wmn ms_wmn_active ms_yth ms_yth_active nocorrupt"
local uvars_h6 "chf_age  ms_nochief trust_lc_chf"
local uvars_h7 "osusu trust_cg trust_chf trust_lc trust_ngo trust_out trust_own"
local uvars_h8 "fishcoop mbr_pta mbr_rel mbr_sav mbr_seed mbr_soc mbr_wom mbr_yth"
local uvars_h9 "disp_ind vis_pc"
local uvars_h10 "stand_lc stand_pc stand_sc stand_wdc"
local uvars_h11 "no_conflict no_fight no_theft no_witch"
local uvars_h12 "vh_fem vh_youth"


local all_outcomes = "`uvars_h1'" + " `uvars_h2'" + " `uvars_h3'" + " `uvars_h4'" + " `uvars_h5'" +  " `uvars_h6'" + " `uvars_h7'" + " `uvars_h8'" + " `uvars_h9'" + " `uvars_h10'" + " `uvars_h11'" + " `uvars_h12'" 

* Calculating means
foreach var of varlist  `all_outcomes' {
	qui sum `var' if t1==0
	
	* Store mean in mata
	scalar mean_`var' = r(mean)
	mata: mean_`var' = st_numscalar(" mean_`var'")	
}

* And regression on treatment 
foreach var of varlist  `all_outcomes'{
	qui reg `var' `indepvars', r
	scalar n = e(N) 
	mata: `var'_N = st_numscalar("e(N)")
	mata: te_`var' = st_matrix("r(table)")[1,1], st_matrix("r(table)")[2,1], st_matrix("r(table)")[4,1], `var'_N
}

* Concatenate everything
local table_vars = "`all_outcomes'"
local check : word 1 of `table_vars'
foreach var of varlist `table_vars'{
	mata: `var' = mean_`var', te_`var'
	
	* First variable defines the matrix
	if "`var'"=="`check'"{
		mata: A = (`var')
	}
	
	* Everything else is appended
	else{
		mata: A = (A \ `var')
	}	
} 

* Make table
mata: st_matrix("A", A)
preserve
	clear
	svmat A
	ren A1 Mean_Controls
	ren A2 Treatment_Effect
	ren A3 Standard_Error
	ren A4 Naive_p_value
	ren A5 N
	
	gen varname = ""
	local loopto : word count `table_vars'
	forvalues i = 1/`loopto'{
		local outcome : word `i' of `table_vars'
		replace varname = "`outcome'" if _n == `i'
	}
	
	order varname
	
	outsheet using "tables/Table_A5.csv", comma replace
restore 



********************************************************************************
*********************************** TABLE A6 ***********************************
********************************************************************************

*************
/*  BOMBALI */	
*************

use "data/SES_analysis.dta", clear
mata: mata clear

local districts BOMBALI BONTHE
local vars_h13 "task_eb law_eb  seekwestern seekwestern_eb air_eb days_eb get_eb hotline_eb protect_eb salt_eb chlorine_eb spread_eb sympt_eb "
* Calculating z-scores
	local indepvars "t1 tothhs road ward*" 
	foreach dis of local districts{
		foreach var of varlist  `vars_h13'{
			 qui sum `var' if district=="`dis'" &t1==0
			 qui gen `var'_mn_`dis'=r(mean)
			 
			 * Store mean in mata
			scalar mn_`var'_`dis' = r(mean)
			mata: mn_`var'_`dis' = st_numscalar(" mn_`var'_`dis'")
			
			qui gen `var'_sd_`dis'=r(sd)
			qui gen sd_`var'_`dis'=(`var'-`var'_mn_`dis')/`var'_sd_`dis'
			* impute missing values
			egen mn_sd_`var'_t_`dis'=mean( sd_`var'_`dis') if t1==1
			replace sd_`var'_`dis'=mn_sd_`var'_t_`dis' if t1==1 & sd_`var'_`dis'==.
			replace sd_`var'_`dis'=0 if t1==0 & sd_`var'_`dis'==.
			local zscore_string_13_`dis'="`zscore_string_13_`dis''" + " sd_`var'_`dis'"
			*di "`zscore_string_13_`dis''"
		}
		
		* Construct mean index, store the average
		egen zscore_all_`dis'=rowmean(`zscore_string_13_`dis'') if district=="`dis'"
		egen zscore_know_`dis'=rowmean(sd_air_eb_`dis' sd_days_eb_`dis' sd_get_eb_`dis' sd_hotline_eb_`dis' sd_protect_eb_`dis' sd_salt_eb_`dis' sd_chlorine_eb_`dis' sd_spread_eb_`dis' sd_sympt_eb_`dis') if district=="`dis'"
		egen zscore_res_`dis'= rowmean(sd_task_eb_`dis' sd_law_eb_`dis' sd_seekwestern_`dis' sd_seekwestern_eb_`dis') if district=="`dis'"
		
		sum zscore_all_`dis' if t1==0 
		scalar mn_zscore_all_`dis' = r(mean)
		sum zscore_know_`dis' if t1==0 
		scalar mn_zscore_know_`dis' = r(mean)
		sum zscore_res_`dis' if t1==0 
		scalar mn_zscore_res_`dis' = r(mean)
		
		mata: mn_zscore_all_`dis' = st_numscalar("mn_zscore_all_`dis'")
		mata: mn_zscore_know_`dis' = st_numscalar("mn_zscore_know_`dis'")
		mata: mn_zscore_res_`dis' = st_numscalar("mn_zscore_res_`dis'")
		

		*Regress each on treatment and balancing, store results
		local reg_eb_`dis' = "zscore_all_`dis'" + " `vars_h13'" 
		local regs `reg_eb_`dis'' zscore_know_`dis' zscore_res_`dis'
		foreach var of varlist  `regs'{
			qui reg `var' `indepvars' if district=="`dis'", r 
			if `var'==zscore_all_`dis'|`var'==zscore_know_`dis'|`var'== zscore_res_`dis'{
				mata: te_`var' = st_matrix("r(table)")[1,1], st_matrix("r(table)")[2,1], st_matrix("r(table)")[4,1]
			}
			else {
				mata: te_`var'_`dis' = st_matrix("r(table)")[1,1], st_matrix("r(table)")[2,1], st_matrix("r(table)")[4,1]
			}	
		}
		
	* Concatenate everything
		local table_eb_`dis' = "zscore_all_`dis'" + " `vars_h13'"
		local table_vars `table_eb_`dis'' zscore_know_`dis' zscore_res_`dis'
		
		foreach var of varlist `table_vars'{
			* First variable defines the matrix
			if `var'==zscore_all_`dis'|`var'==zscore_know_`dis'|`var'==zscore_res_`dis '{
				mata: `var' = mn_`var', te_`var'
			}
			else{
				mata: `var'_`dis' = mn_`var'_`dis', te_`var'_`dis'
			}
		}
		
		* Make table
		mata: A_`dis'= zscore_all_`dis'\zscore_know_`dis'\zscore_res_`dis'
		
		local disvars
		foreach thing in `vars_h13'{
			local disvars `disvars'  `thing'_`dis' 
		}
		foreach x in `disvars'{
			mata: A_`dis'= (A_`dis' \ `x')
		}
		
		mata: st_matrix("A_`dis'", A_`dis')
		preserve
		clear
		svmat A_`dis'
		ren A*1 Mean_Controls
		ren A*2 Treatment_Effect
		ren A*3 Standard_Error
		ren A*4 p_value
	
		gen varname = ""
		local vars zscore_all_`dis' zscore_know_`dis' zscore_res_`dis' `disvars'
		local loopto : word count  `vars'
		forvalues i = 1/`loopto'{
			local outcome : word `i' of `vars'
			replace varname = "`outcome'" if _n == `i'
	
		}
		outsheet using "tables/Table_A6_`dis'.csv", comma replace
		
		restore
	}
	
	
********************************************************************************
*********************************** TABLE A7 ***********************************
********************************************************************************
use "data/public_expert_data.dta", clear	

local CDD  CDDc_SQ CDDc_MS CDDc_MS_TR CDDt_SQ CDDt_MS CDDt_MS_TR
foreach var of varlist `CDD'{
	di "`var'"
	qui sum `var'
	scalar mean_`var' = r(mean)
	mata: mean_`var' = st_numscalar(" mean_`var'")
	scalar sdev_`var' = r(sd)
	mata: sdev_`var' = st_numscalar("sdev_`var'")
	
	mata: list_`var' = mean_`var', sdev_`var'
}

mata: a7 = list_CDDc_SQ\ list_CDDc_MS \ list_CDDc_MS_TR ///
		  \ list_CDDt_SQ\ list_CDDt_MS \ list_CDDt_MS_TR
		  
* Make table
mata: st_matrix("a7", a7)
preserve
	clear
	svmat a7
	ren a71 Mean
	ren a72 SDev
	
	gen varname = ""
	local names "list_CDDc_SQ list_CDDc_MS  list_CDDc_MS_TR list_CDDt_SQ list_CDDt_MS  list_CDDt_MS_TR"
	forvalues i = 1/6{
		local outcome : word `i' of `names'
		replace varname = "`outcome'" if _n == `i'
	}
	
	
	outsheet using "tables/Table_A7.csv", comma replace
restore 


********************************************************************************
************************************ FIGURE A1 **********************************
********************************************************************************

use "temp/temp_panel_pgoods.dta", clear

*Relabel variables for figure
label var f_psch "Primary school"
label var f_phu "Public health unit"
label var f_well "Well"
label var f_dryflr "Drying floor"
label var f_grnstr "Grain store"
label var f_comcntr "Community center"
label var f_palava "Palava hut"
label var f_barrie "Community barrie"
label var f_market "Market"
label var f_latrine "Latrine"
label var f_tba "Traditional birth attendant"
label var f_sports "Sports field"

*************
/*  Figure */	
*************

foreach var of varlist f_psch f_phu f_well f_dryflr f_grnstr f_comcntr f_palava  f_barrie f_market f_latrine f_tba f_sports{
	
	qui reg `var' `indepvars' if post==1, robust
	local t_sr= _b[t1]/_se[t1]
	local p_s =2*ttail(e(df_r),abs(`t_sr')) 	
	local p_sr : di %3.2f `p_s'
	
	qui reg `var' `indepvars' if post==2, robust
	local t_lr= _b[t1]/_se[t1]
	local p_l =2*ttail(e(df_r),abs(`t_lr')) 	
	local p_lr : di %3.2f `p_l'
	
	foreach time in sr lr{
	local time_lbl = upper(`"`time'"')
		if `p_`time''<0.01 {
			local sub_`time' "{it: p{subscript:`time_lbl'}} <0.01"
		}
		
		else {
			local sub_`time' "{it: p{subscript:`time_lbl'}} =`p_`time''"
		}
	}

	
	bysort t1 post: egen m_`var'=mean(`var') 
	local label : var label `var'
	label var m_`var' `"`label"'
	local title: var label m_`var' 
	twoway (bar  m_`var' t1 if post==1, hor  barw(0.8) color(ltblue) ) (scatter t1 m_`var' if post==2, m(diamond)), nodraw name(g_`var', replace) ytitle("") xtitle("") title("`title'", size(*0.8))  text(1.4 0.99 "`sub_sr'", size(.25cm)) text(0.8 0.99 "`sub_lr'", size(.25cm)) legend( label(1 "Short run") label(2 "Long run") rows(1)) yscale(r(0 0.5)) ylabel(none 0 "C" 1 "T", noticks nogrid) graphregion(color(white)) xscale(r(0 1))  xlabel(0(0.1)1)
	
	local glist_pgoods `glist_pgoods' g_`var'	

}

*Save and export figure 

grc1leg2 `glist_pgoods', rows(6) 
graph export "figures/figa1.png", replace



********************************************************************************
************************************ FIGURE A2 **********************************
********************************************************************************

use "temp/temp_panel.dta", clear

*Relabel vars for figure 

label var betteroff "Better off"
label var petty "Petty trading"
label var tot_goods "Number of goods accessible"
label var tot_newbiz "Number of new businesses"
label var tot_petty "Number of petty businesses"


*************
/*  Figure */	
*************


foreach var of varlist betteroff petty tot_goods tot_newbiz tot_petty{
	
	qui reg `var' `indepvars' if post==1, robust
	local t_sr= _b[t1]/_se[t1]
	local p_s =2*ttail(e(df_r),abs(`t_sr')) 	
	local p_sr : di %3.2f `p_s'
	
	qui reg `var' `indepvars' if post==2, robust
	local t_lr= _b[t1]/_se[t1]
	local p_l =2*ttail(e(df_r),abs(`t_lr')) 	
	local p_lr : di %3.2f `p_l'
	
	foreach time in sr lr{
	
		local time_lbl = upper(`"`time'"')
		
		if `p_`time''<0.01 {
			local sub_`time' "{it: p{subscript:`time_lbl'}} <0.01"
		}
		
		else {
			local sub_`time' "{it: p{subscript:`time_lbl'}} =`p_`time''"
		}
	}
	
	bysort t1 post: egen m_`var'=mean(`var') 
	local label : var label `var'
	label var m_`var' `"`label"'
	local title: var label m_`var' 
	
	qui sum m_`var'
	local xmax `r(max)'

	
	if `xmax'<1 {
	twoway (bar  m_`var' t1 if post==1, hor  barw(0.8) color(ltblue) ) (scatter t1 m_`var' if post==2, m(diamond)), nodraw name(g_`var', replace) ytitle("") xtitle("") title("`title'", size(*0.8))  text(1.4 0.99 "`sub_sr'", size(.25cm)) text(1 0.99 "`sub_lr'", size(.25cm)) legend( label(1 "Short run") label(2 "Long run") rows(1)) yscale(r(0 0.5)) ylabel(none 0 "C" 1 "T", noticks nogrid) graphregion(color(white)) xscale(r(0 1))  xlabel(0(0.1)1)
	}
	
	else{
		twoway (bar  m_`var' t1 if post==1, hor  barw(0.8) color(ltblue) ) (scatter t1 m_`var' if post==2, m(diamond)), nodraw name(g_`var', replace) ytitle("") xtitle("") title("`title'", size(*0.8)) text(1.4 9.9 "`sub_sr'", size(.25cm)) text(1 9.9 "`sub_lr'", size(.25cm))legend( label(1 "Short run") label(2 "Long run") rows(1)) yscale(r(0 0.5)) ylabel(none 0 "C" 1 "T", noticks nogrid) graphregion(color(white)) xscale(r(0 10))  xlabel(0(1)10)
	
	}
	
	local glist_econwelf `glist_econwelf' g_`var'
	
}


*Save and export figure 

grc1leg2 `glist_econwelf', rows(3)
graph export "figures/figa2.png", replace



********************************************************************************
************************************ FIGURE A3 **********************************
********************************************************************************
use "temp/temp_panel_family.dta", clear

corr fam_b fam_a if post==2
local corr : di %5.3g r(rho)
twoway (scatter fam_b fam_a) (lfit fam_b fam_a) if post==2, xtitle("Count of hardware items") ytitle("Count of sofware items") title("Correlation b/n hardware and software counts") subtitle("Corr: `corr'") legend(off)
graph export "figures/figa3_panela.png", replace


drop fam*

local fam_a "vdc vis_lc vis_wdc f_psch f_phu f_well f_dryflr f_grnstr f_comcntr f_palava f_barrie f_market" //12
local fam_b "vdc proposal commfarm commtchr meet_com trust_lc_chf osusu  trust_cg trust_chf trust_lc  trust_out trust_own mbr_pta mbr_soc vis_lc vis_wdc disp_ind  stand_lc stand_pc stand_sc stand_wdc no_fight no_theft no_witch"  //24


foreach fam in a b{
	*Number of items in each family for each village 	
	egen fam_`fam'= rowtotal(`fam_`fam'')
}

keep id_vill  post t1 fam*
reshape wide fam_a fam_b, i(id_vill t1) j(post)
gen diff_fam_a= fam_a2-fam_a0
gen diff_fam_b= fam_b2-fam_b0


corr diff_fam_b diff_fam_a if t1==1
local corr : di %5.3g r(rho)

twoway (scatter diff_fam_b diff_fam_a) (lfit diff_fam_b diff_fam_a) if t1==1, xtitle("Change in hardware item count") ytitle("Change in software item count") title("Corr b/n change in hardware and software counts, T group") subtitle("Corr: `corr'") legend(off)
graph export "figures/figa3_panelb.png", replace



********************************************************************************
******************************* IN-TEXT ESTIMATES ******************************
********************************************************************************

* Maarten, please add the page numbers from the final draft

*************
/*  Priming Forecasts */	
*************
use "data/public_expert_data", clear
drop if coauthor == 1

* included as requested, not currently in the draft. 

ttest famA, by(version)
ttest famB, by(version)
ttest CDDc_SQ, by(version)

*************
/*  Action vs. Knowledge */	
*************
use "data/SES_analysis.dta", clear

* Note: ebola violence omitted due to lack of variation (zero variation)
* Note: hidden ebola omitted due to lack of variation (zero variation)
* Note: seeking western medicine outcomes omitted to to lack of variation (v. little variation)
local indepvars "t1 tothhs road ward*" 
local vars_action "task_eb law_eb"
local vars_knowledge "get_eb sympt_eb protect_eb days_eb air_eb hotline_eb spread_eb salt_eb chlorine_eb"

* Full Sample

* We also pre-specified a secondary analysis to examine knowledge versus action outcomes separately. For the latter, we find a positive and significant effect for the two action outcomes (namely creating an Ebola task force and bye-laws) of 0.153 standard deviation units (standard error 0.064) in the full sample

preserve
	foreach x in "action" "knowledge"{
		foreach var of varlist  `vars_`x'' {
			local l = `l' + 1
			qui sum `var' if t1==0
			qui gen `var'_mean=r(mean)
			qui gen `var'_sd=r(sd)
			qui gen std_`x'_`l'=(`var'-`var'_mean)/`var'_sd
			* impute missing values
			egen mean_std_`x'_`l'_t=mean( std_`x'_`l') if t1==1
			replace std_`x'_`l'=mean_std_`x'_`l'_t if t1==1 & std_`x'_`l'==.
			replace std_`x'_`l'=0 if t1==0 & std_`x'_`l'==.
			local zscore_string_`x'="`zscore_string_`x''" + " std_`x'_`l'"
				}
		
		egen zscore_`x'=rowmean(`zscore_string_`x'')
		local zscore_string_`x'=""
		local l = 0
		drop *_mean *_sd mean_std_*
		
		di "Full " "`x'"
		reg zscore_`x' `indepvars', robust
		estimates store actknwol_`x'
		
	}
restore

* although note that this estimate is not statistically distinguishable from zero in the Bombali-only subsample. 


* Bombali
preserve
	keep if district == "BOMBALI"
	foreach x in "action" "knowledge"{
		foreach var of varlist  `vars_`x'' {
			local l = `l' + 1
			qui sum `var' if t1==0
			qui gen `var'_mean=r(mean)
			qui gen `var'_sd=r(sd)
			qui gen std_`x'_`l'=(`var'-`var'_mean)/`var'_sd
			* impute missing values
			egen mean_std_`x'_`l'_t=mean( std_`x'_`l') if t1==1
			replace std_`x'_`l'=mean_std_`x'_`l'_t if t1==1 & std_`x'_`l'==.
			replace std_`x'_`l'=0 if t1==0 & std_`x'_`l'==.
			local zscore_string_`x'="`zscore_string_`x''" + " std_`x'_`l'"
				}
		
		egen zscore_`x'=rowmean(`zscore_string_`x'')
		local zscore_string_`x'=""
		local l = 0
		drop *_mean *_sd mean_std_*
		
		di "Bombali " "`x'"
		reg zscore_`x' `indepvars', robust
		estimates store actknwol_`x'
		
	}
restore

* Bonthe
preserve
	keep if district == "BONTHE"
	foreach x in "action" "knowledge"{
		foreach var of varlist  `vars_`x'' {
			local l = `l' + 1
			qui sum `var' if t1==0
			qui gen `var'_mean=r(mean)
			qui gen `var'_sd=r(sd)
			qui gen std_`x'_`l'=(`var'-`var'_mean)/`var'_sd
			* impute missing values
			egen mean_std_`x'_`l'_t=mean( std_`x'_`l') if t1==1
			replace std_`x'_`l'=mean_std_`x'_`l'_t if t1==1 & std_`x'_`l'==.
			replace std_`x'_`l'=0 if t1==0 & std_`x'_`l'==.
			local zscore_string_`x'="`zscore_string_`x''" + " std_`x'_`l'"
				}
		
		egen zscore_`x'=rowmean(`zscore_string_`x'')
		local zscore_string_`x'=""
		local l = 0
		drop *_mean *_sd mean_std_*
		
		reg zscore_`x' `indepvars', robust
		estimates store actknwol_`x'
		
	}
restore

*************
/*  Pooled Expert Predictions */	
*************
use "data/public_expert_data", clear

* As a group, the experts predicted a baseline take up rate of 36 percent

sum CDDc_SQ



***************************
*   PART III: TIDY UP   *
***************************

********************************************************************************
******************************* Erase Temp Files *******************************
********************************************************************************
rm "temp/temp_panel2009.dta"
rm "temp/temp_panel2016.dta"
rm "temp/temp_zscores2009.dta"
rm "temp/temp_zscores2016.dta"
rm "temp/temp_gbf_hetero.dta"
rm "temp/temp_panel.dta"
rm "temp/temp_panel_pgoods.dta"
rm "temp/temp_panel_family.dta"

